<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to get and modify data</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to execute <code>select</code> statements</h1>
    <h2>A method of the PDO class for preparing a SQL statement</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <pre>
      prepare($sql_statement)
      // Prepares the specified SQL statement for execution and returns a 
      // PDOStatement object. Within the SQL statement, you can use a 
      // colon (:) to add parameters to the statement.
      </pre>
    </div>
    <h2>Two methods of the PDOStatement class for executing a statement</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      bindValue($param, $value)
      // Binds the specified value to the specified parameter in the prepared statement. 
      
      execute() 
      // Executes the prepared statement.
      </pre>
    </div>
    <h2>How to execute a SQL statement that doesn’t have parameters</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $query = "SELECT * FROM products";
      $statement = $db->prepare($query);
      $statement->execute();
      </pre>
    </div>
    <h2>How to execute a SQL statement that has a parameter</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $query = "SELECT * FROM products WHERE categoryID = :category_id";
      $statement = $db->prepare($query);
      $statement->bindValue(':category_id', $category_id);
      $statement->execute();
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>To prepare a SQL statement, you use the <code>prepare()</code> method of the PDO object. It requires just one argument, which is the SQL statement to be executed.</li>
        <li>To execute a SQL statement, you use the <code>execute()</code> method of the PDOStatement object.</li>
        <li>To bind a variable to a parameter, you can use the <code>bind()</code> method of the PDOStatement object.</li>
        <li>To identify a parameter in a SQL statement, you can code a colon (<code>:</code>) followed by the name of the parameter.</li>
        <li>If the SQL statement is a SELECT statement that returns a result set, the execute method stores the result set in the PDOStatement object. Then, you can get the data from the PDOStatement object by using the techniques in the next two pages.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>