<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to work with all the rows of a result set</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to work with all the rows of a result set</h1>
    <h2>Another method of the PDOStatement class</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <pre>
      fetchAll() 
      // Returns an array for all of the rows in the result set.
      </pre>
    </div>
    <h2>Code that returns a result set of two or more rows</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $query = "SELECT productCode, productName, listPrice
                FROM products
                WHERE categoryID = :category_id;"
      $statement = $db->prepare($query);
      $statement->bindValue(":category_id", $category_id);
      $statement->execute();
      $products = $statement->fetchAll();
      $statement->closeCursor();
      </pre>
    </div>
    <h2>How to use a foreach statement to display the result set in an HTML table</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      &lt;!-- HTML code to begin a table goes here --&gt;
      &lt;?php foreach ($products as $product) { ?&gt;
        &lt;td&gt;&lt;?php echo $product['productCode']; ?&gt;&lt;/td&gt;
        &lt;td&gt;&lt;?php echo $product['productName']; ?&gt;&lt;/td&gt;
        &lt;td&gt;&lt;?php echo $product['listPrice']; ?&gt;&lt;/td&gt;
      &lt;/tr&gt;
      &lt;?php } ?&gt;
      &lt;!-- HTML code to end table goes here --&gt;
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>When a PDOStatement object contains a result set, you can use the <code>fetchAll()</code> method to return an array that contains that result set. Then, you can use the <code>closeCursor()</code> method to close the connection to the database.</li>
        <li>To loop through the elements in an array, you can use a <code>foreach</code> statement to define a <code>foreach</code> loop that processes one element of the array each time through the loop.</li>
        <li>The second syntax for the <code>foreach</code> statement makes it easier to use the <code>foreach</code> statement with other control statements because it doesn’t require the use of braces.</li>
        <li>When you use the second syntax with other control statements, you code a colon after the clause that starts each control statement, and you end each control statement with an appropriate end statement. For example, you end an <code>if</code> statement with an <code>endif</code> statement.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>