<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to handle exceptions</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to handle exceptions</h1>
    <h2>The syntax for a try/catch statement</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <pre>
       try {
         // statements that might throw an exception
       } catch (ExceptionClass $exception_name) {
         // statements that handle the exception
       }
      </pre>
    </div>
    <h2>The syntax for executing a method of any object</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $objectName->methodName(argumentList)
      </pre>
    </div>
    <h2>How to handle a PDO exception</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      try { 
        $db = new PDO($dsn, $username, $password);
        echo("You are connected to the database!&lt;/p&gt;\n");
      } catch (PDOException $e) {
        $error_message = $e->getMessage();
        echo(&lt;p&gt;An error occurred while connecting to the database: $error_message);
        exit;
      }
      </pre>
    </div>
    <h2>How to handle any type of exception</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      try {
        // statements that might throw an exception
      } catch (Exception $e) {
        $error_message = $e->getMessage(); 
        echo(&lt;p&gt;An error occurred while connecting to the database: $error_message);
        exit;
      }
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>An <span style="background-color: yellow;">exception</span> is an object that contains information about an error that has occurred. Some PHP statements <span style="background-color: yellow;">throw</span> exceptions when they encounter an error. If an exception isn’t handled, the application ends prematurely.</li>
        <li>To handle exceptions, you use a <code>try/catch</code> statement. First, you code a <code>try</code> block around any PHP statements that might throw an exception. Then, you code a <code>catch</code> block that catches the exception. This is known as <span style="background-color: yellow;">exception handling</span>.</li>
        <li>The Exception class includes all types of exceptions, and all other exceptions are subclasses of the Exception class. The PDOException class is used for errors thrown by the PDO library.</li>
        <li>To call a <span style="background-color: yellow;">method</span> from any object, you code the name of the object, followed by <code>-&gt;</code>, followed by the name of the method, followed by a set of parentheses. Within the parentheses, you code the arguments that are required by the method, separating multiple arguments with commas.</li>
        <li>All Exception objects provide a <code>getMessage()</code> method that lets you get the error message.</li>
        <li>If an exception is thrown in the try block, any remaining statements in the try block are skipped and the statements in the catch block are executed. If no exceptions are thrown in the try block, the catch block is skipped.</li>
        <li>You’ll learn more about exception handling in chapter 15.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>