<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to work with the first row of a result set</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to work with the first row of a result set</h1>
    <h2>Two more methods of the PDOStatement class</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <pre>
      fetch() 
      // Returns an array for the next row in the result set. This array
      // is indexed by both a string index for the column name and a numeric 
      // index for the column position. If no array is available, this 
      // method returns a FALSE value. 
      
      closeCursor()
      // Closes the cursor and frees the connection to the server so 
      // other SQL statements may be issued.
      </pre>
    </div>
    <h2>Code that returns a result set that contains one row</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $query = "SELECT productCode, productName, listPrice 
                FROM products 
                WHERE productID = :product_id";
      $statement = $db->prepare($query);
      $statement->bindValue(':product_id', $product_id);
      $statement->execute();
      $product = $statement->fetch();
      $statement->closeCursor();
      </pre>
    </div>
    <h2>Code that uses a string index to access each column</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $product_code = $product['productCode'];
      $product_name = $product['productName'];
      $product_list_price = $product['listPrice'];
      </pre>
    </div>
    <h2>Code that uses a numeric index to access each column</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $product_code = $product[0];
      $product_name = $product[1];
      $product_list_price = $product[2];
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>An array can store one or more elements.You can use the <code>fetch()</code> method of a PDOStatement object to get an array for the first row (or next row) of a result set. Then, you can use column names or numeric indexes to access the data that’s stored in that row.</li>
        <li>To refer to the elements in an array, you use an index. If you use numeric indexes, 0 refers to the first element, 1 to the second element, and so on.</li>
        <li>You can use the <code>fetch()</code> method of a PDOStatement object to get an array for the first row (or next row) of a result set. Then, you can use column names or numeric indexes to access the data that’s stored in that row.</li>
        <li>Arrays were covered in chapter 11.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>