<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to get data from an array of check boxes</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />
  </head>
  <body>
    <h1>How to get data from an array of check boxes</h1>
    <h2>The HTML that stores three related check boxes in an array</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>      
      &lt;input type="checkbox" id="pep" name="top[]" checked /&gt;Pepperoni&lt;br /&gt;
      &lt;input type="checkbox" id="msh" name="top[]" checked /&gt;Mushrooms&lt;br /&gt;
      &lt;input type="checkbox" id="olv" name="top[]" checked /&gt;Olives&lt;br /&gt;
      </pre>
    </div>
    <h2>PHP that accesses the array and its values</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      &lt;php
      $toppings = filter_input(INPUT_POST, 'top', 
                               FILTER_SANITIZE_SPECIAL_CHARS, FILTER_REQUIRE_ARRAY);
      if ($toppings !== NULL) { 
        $top1 = $toppings[0]; // $top1 is pep
        $top2 = $toppings[1]; // $top2 is olv
        $top3 = $toppings[2]; // $top3 is not set – throws an error
      }
      ?&gt;
      </pre>
    </div>
    <h2>PHP that uses a loop to process the array</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>      
      &lt;php
      $toppings = filter_input(INPUT_POST, 'top', 
                               FILTER_SANITIZE_SPECIAL_CHARS, FILTER_REQUIRE_ARRAY);
      if ($toppings !== NULL) { 
        echo("&lt;p&gt;");
        foreach($toppings as $key => $value) {
          echo("$key = $value&lt;br /&gt;\n");
        }
        echo("&lt;/p&gt;\n");
      } else {
        echo("No toppings selected.&lt;/p&gt;\n");
      }
      ?&gt;
      </pre>
    </div>
    <ul>
      <li>If a check box name ends with [], PHP adds the check box to an array that’s nested in the $_GET or $_POST array. This allows multiple values to be submitted with the same name.</li>
      <li>If none of the check boxes in an array of check boxes are selected, the array won’t be set in the $_GET or $_POST array.</li>
      <li>If you’re going to use the checkbox values, you should use a PHP function like the filter_input() function to get the values of the array and to make sure they are safe. To do that, you can use filters like the ones shown on this page.</li>
    </ul>
    <p><a href=".">Back</a></p>
  </body>
</html>