<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to code if/else statements</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />
  </head>
  <body>
    <h1>How to code <code>if/else</code> statements</h1>
    <h2>An <code>if</code> clause with one statement and no braces (<span style="color: #F00;">Not Recommended</span>)</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <code>
      if (!isset($rate)) $rate = 0.075; // Jim... Not recommended
      </code>
    </div>
    <h2>An <code>if</code> clause with one statement and braces (<span style="color: #F00;">Recommended</span>)</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <code>
      if ($qualified) { // This expression is equivalent to $qualified == true.<br />
      &nbsp;&nbsp;echo("You qualify for enrollment.");<br />
      }
      </code>
    </div>
    <h2><code>if</code> and <code>else</code> clauses with one statement each and no braces  (<span style="color: #F00;">Not Recommended</span>)</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <code>
      if ($age >= 18)<br />
      &nbsp;&nbsp;echo("You may vote.");<br />
      else<br />
      &nbsp;&nbsp;echo("You may not vote.");
      </code>
    </div>
    <h2>Why you should always use braces with <code>else</code> clauses
</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <code>
      if ($age >= 18)<br />
      &nbsp;&nbsp;echo("You may vote.");<br />
      else<br />
      &nbsp;&nbsp;echo("You may not vote.");<br />
      $may_vote = false; // This statement isn't a part of the else clause.
      </code>
    </div>
    <h2>Braces make your code easier to modify or enhance</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <code>
      if ($score >= 680) {<br />
      } else {<br />
      }
      </code>
     </div>hp if (1=1) {
     }
    <h2>A nested if statement to determine if a year is a leap year</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <code>
      $is_leap_year = false;<br />
      if ($year % 4 == 0) {<br />
      &nbsp;&nbsp;if ($year % 100 == 0) {<br />
      &nbsp;&nbsp;&nbsp;&nbsp;if ($year % 400 == 0) {<br />
      &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;$is_leap_year = true; // divisible by 4, 100, and 400<br />
      &nbsp;&nbsp;&nbsp;&nbsp;} else <br />
      &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;$is_leap_year = false; // divisible by 4 and 100 but not 400<br />
      &nbsp;&nbsp;&nbsp;&nbsp;}<br />
      &nbsp;&nbsp;} else {<br />
      &nbsp;&nbsp;&nbsp;&nbsp;$is_leap_year = true; // divisible by 4, but not 100 <br />
      &nbsp;&nbsp;}<br />
      } else {<br />
      &nbsp;&nbsp;$is_leap_year = false; // not divisible by 4<br />
      }
      </code>
     </div>
     <ul>
       <li>If you only have one statement after an if statement or an else clause, you don’t have to put braces around that statement.<br />
       <strong>Jim... I do not recommend not using braces. At some future oint yu may need to add a statement and you may forget to add the braces at that time and will get wrong results.</strong></li>
       <li>You can nest an if statement within the if, else if, or else clause of another if statement. This nesting can continue many layers deep.</li>
     </ul>
    <p><a href=".">Back</a></p>
  </body>
</html>