<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to use the conditional and null coalesce operators</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />
  </head>
  <body>
  <h1>How to use the conditional and null coalesce operators</h1>
    <h2>Examples that use the conditional operator</h2>
    <h3>Set a string based on a comparison</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       $message = ($age >= 18) ? 'Can vote' : 'Cannot vote';  // Ternary Operator
      </pre>
    </div>
    <h3>Set a variable depending on whether another variable is not null</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       $greeting = (isset($first_name)) ? $first_name : 'Guest'; // Ternary Operator
      </pre>
    </div>
    <h3>Select a singular or plural ending based on a value</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $ending = ($error_count == 1) ? '' : 's'. // Ternary Operator
      $message = 'Found ' . $error_count . ' error' . $ending . '.'; 
      </pre>
    </div>
    <h3>Return one of two values based on a comparison</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      return($number > $highest) ? $highest : $number;  // Ternary Operator
      </pre>
    </div>
    <h3>Bound a value within a fixed range</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       $value = ($value > $max) ? $max : (($value &lt; $min) ? $min : $value); // Ternary Operator
      </pre>
    </div>
    <h2>The first example rewritten with an if statement</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      if ($age >= 18) {
        $message = 'Can vote';
      } else {
        $message = 'Cannot vote';
      } 
      </pre>
    </div>
    <h2>The fifth example rewritten with an if statement</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      if ($value &gt; $max) {
        $value = $max;
      } else if ($value &lt; $min) {
        $value = $min;
      } 
      </pre>
     </div>
    <h2>Examples that use the null coalesce operator</h2>
    <h3>Set a variable depending on whether another variable is not null</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $greeting = $first_name ?? 'Guest'; // Ternary Operator
      </pre>
     </div>
    <h3>Set a variable depending on whether multiple variables are not null</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $greeting = $first_name ?? $email_address ?? 'Guest';
      </pre>
     </div>
     <ul>
       <li>A ternary operator has three operands. The conditional operator is the only ternary operator available from PHP, and it provides a compact way to code an if statement.</li>
       <li>With PHP 7 and later, the null coalesce operator (??) provides a concise way to check whether a value has been set and is not null. If so, it returns that value. Otherwise, it returns another specified value.</li>
     </ul>
    <p><a href=".">Back</a></p>
  </body>
</html>   