<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to manage a session</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />
  </head>
  <body>
    <h1>How to manage a session</h1>
    <h2>Get the name of the session</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      cookie $name = session_name(); // By default, PHPSESSID
      </pre>
    </div>
    <h2>Get the value of the session ID</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $id = session_id(); // For example, l1jef1foi1g8u6qnui4f8b6e14
      </pre>
    </div>
    <h2>Set the session ID</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      session_id('abc123');
      </pre>
    </div>
    <h2>How to end a session</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $_SESSION = array(); // Clear session data from memory
      session_destroy(); // Clean up the session ID
      </pre>
    </div>
    <h2>Delete the session cookie from the browser</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       $name = session_name();  // Get name of session cookie
       $expire = strtotime('-1 year');  // Create expire date in the past
       $params = session_get_cookie_params();  // Get session params
       $path = $params['path']; 
       $domain = $params['domain']; 
       $secure = $params['secure']; 
       $httponly = $params['httponly']; 
       setcookie($name, '', $expire, $path, $domain, $secure, $httponly);
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>A session ends when the user closes the browser, when a specified amount of time elapses without a request, or when the code calls the <code>session_destroy()</code> function.</li>
        <li>To remove all data associated with the session from the client and the server, you can clear the session data from memory, call the <code>session_destroy()</code> function, and use the <code>setcookie()</code> function to delete the session cookie.</li>
        <li>The <code>session_name()</code> function gets the name of the session cookie. By default, the session cookie has a name of "PHPSESSID"<./li>
        <li>The <code>session_get_cookie_params()</code> function gets an associative array that contains all of the parameters for the session cookie.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>