<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to work with anonymous functions</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />
  </head>
  <body>
    <h1>How to work with anonymous functions</h1>
    <h2>How to create and use an anonymous function</h2>
    <h3>A custom sorting function</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $compare_function = function($left, $right) { 
        $l = (float) 
        $left; 
        $r = (float) $right; 
        if ($l &lt; $r) { return -1;  }
        if ($l > $r) { return 1; }
        return 0; 
      }; 
      </pre>
    </div>
    <h3>Code that tests the custom sorting function</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $a = 3; 
      $b = 5; 
      $result = $compare_function($a, $b); // -1 
      </pre>
    </div>
    <h3>Code that uses the custom sorting function</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       $values = array(5, 2, 4, 1, 3); 
       usort($values, $compare_function); // 1, 2, 3, 4, 5
      </pre>
    </div>
    <h2>A custom sorting function that takes advantage of PHP 7 features</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       $compare_function = function(float $left, float $right) { 
         return $left <=> $right; // the "spaceship" operator
       };
      </pre>
    </div>
    <ul>
      <li>An anonymous function is a function that doesn’t have a name. You can store an anonymous function in a variable and use it as a variable function.</li>
      <li>The spaceship operator (<code><=></code>) is available from PHP 7 and later and is often useful when sorting values.</li>
    </ul>
    <p><a href=".">Back</a></p>
  </body>
</html>