<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to Pass Arguments by Value and Reference</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />
  </head>
  <body>
    <h1>How to Pass Arguments by Value and Reference</h1>
    <h2>An argument passed by value</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <code>
      function add_3_by_val($value) {<br />
      &nbsp;&nbsp;$value += 3; <br />
      &nbsp;&nbsp;echo("&lt;p&gt;Value: $value&lt;/p&gt;\n");
      } <br />
      $number = 5;<br />
      add_3_by_val($number);<br />
      echo("&lt;p&gt;Number: $number&lt;/p&gt;\n");
      </code>
      <?php
      function add_3_by_val($value) {
        $value += 3; 
        echo("<p>Value: $value</p>\n");
      } 
      $number = 5;
      add_3_by_val($number);
      echo("<p>Number: $number</p>\n");
      ?>
    </div>
    <h2>An argument passed by reference</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <code>
      function add_3_by_ref(&$value) {<br />
      &nbsp&nbsp;$value += 3; <br />
      &nbsp;&nbsp;echo("&lt;p&gt;Value: $value&lt;/p&gt;\n"); // Displays 8<br />
      } <br />
      $number = 5; <br />
      add_3_by_ref($number); <br />
      &nbsp;&nbsp;echo("&lt;p&gt;Value: $value&lt;/p&gt;\n"); // Displays 8
      </code>
      <?php
      function add_3_by_ref(&$value) {
        $value += 3; 
        echo("<p>Value: $value</p>\n"); // Displays 8
      } 
      $number = 5;
      add_3_by_ref($number);
      echo("<p>Number: $number</p>\n"); // Displays 8
      ?>
    </div>
    <h2>How to modify a string that’s passed by reference</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <code>
      function wrap_in_tag(&$text, $tag) {<br />
      &nbsp;&nbsp;$before = '&lt;' . $tag . '&gt;'; <br />
      &nbsp;&nbsp;$after = ''; <br />
      &nbsp;&nbsp;$text = $before . $text . $after; <br />
      } <br />
      $message = 'Value out of range.'; <br />
      wrap_in_tag($message, 'p'); <br />
      echo("&lt;p&gt;$message&lt;/p&gt;\n"); // Value out of range.
      </code>
      <?php
      function wrap_in_tag(&$text, $tag) {
        $before = '<' . $tag . '>'; 
        $after = ''; 
        $text = $before . $text . $after; 
      } 
      $message = 'Value out of range.'; 
      wrap_in_tag($message, 'p'); 
      echo("$message\n"); // Value out of range.
      ?>
    </div>
    <h2>How to return multiple values</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <code>
      function array_analyze($array, &$sum, &$prod, &$avg) { <br />
      &nbsp;&nbsp;$sum = array_sum($array); <br />
      &nbsp;&nbsp;$prod = array_product($array); <br />
      &nbsp;&nbsp;$avg = $sum / count($array);<br />
      } <br />
      $list = array(1, 4, 9, 16); <br />
      array_analyze($list, $s, $p, $a); <br />
      echo("&lt;p&gt;Sum: $s Product: $p Average: $a&lt;/p&gt;\n");
      </code>
      <?php
      function array_analyze($array, &$sum, &$prod, &$avg) { 
        $sum = array_sum($array); 
        $prod = array_product($array); 
        $avg = $sum / count($array);
      } 
      $list = array(1, 4, 9, 16); 
      array_analyze($list, $s, $p, $a); 
      echo("<p>Sum: $s Product: $p Average: $a</p>\n");
      ?>
    </div>
    <ul>
      <li>By default, all function arguments are passed by value. This means that a copy of the argument is sent to the function. As a result, when the function changes a parameter, it changes a copy of the argument, not the original argument.</li>
      <li>To allow a function to modify the original argument instead of a copy, you can code an ampersand (&) in front of the parameter. In that case, the argument is passed by reference. This means that a reference to the original argument is sent to the function. Then, when the function changes the parameter, it’s actually changing the original argument.</li>
    </ul>
    <p><a href=".">Back</a></p>
  </body>
</html>
