<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to work with variable functions and callbacks</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />
  </head>
  <body>
    <h1>How to work with variable functions and callbacks</h1>
    <h2>How to pass one function to another</h2>
    <h3>A variable function</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $function = (mt_rand(0,1) == 1) ? 'array_sum' : 'array_product'; 
      $values = array(4, 9, 16); 
      $result = $function($values); 
      </pre>
    </div>
    <h3>A function that uses a callback</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      function validate($data, $functions) { 
        $valid = true; 
        foreach ($functions as $function) { 
          $valid = $valid && $function($data); 
        } return $valid; 
      } 
      function is_at_least_18($number) { 
        return $number >= 18; 
      } 
      function is_less_than_62($number) { 
        return $number &lt; 62; 
      } 
      $age = 25; 
      $functions = array('is_numeric', 'is_at_least_18', 'is_less_than_62'); 
      $is_valid_age = validate($age, $functions); // true 
      </pre>
    </div>
    <h2>Language constructs that can’t be used in variable functions</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      die eval echo empty exit
      include include_once isset list print 
      require require_once return unset
      </pre>
    </div>
    <ul>
      <li>A variable function is a function name stored in a variable as a string. When PHP encounters a variable function, it evaluates the variable and attempts to call the function.</li>
      <li>To call a variable function, code the variable name followed by a set of parentheses. Within the parentheses, code the argument list for the function.</li>
      <li>You can use a variable function when the function isn’t known until runtime.</li>
      <li>You can use a variable function in a function that uses a callback. A callback is a function that’s passed as an argument to another function.</li>
      <li>You can’t use the language constructs listed above with variable functions directly. However, you can use a wrapper function that calls one of these constructs in a variable function.</li>
    </ul>
    <p><a href=".">Back</a></p>
  </body>
</html>