<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to work with closures</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />
  </head>
  <body>
    <h1>How to work with closures</h1>
    <h2>How to create a closure</h2>
    <h3>An array of arrays</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $employees = array ( array('name' => 'Ray', 'id' => 5685), array('name' => 'Mike', 'id' => 4302), array('name' => 'Anne', 'id' => 3674), array('name' => 'Pren', 'id' => 1527), array('name' => 'Joel', 'id' => 6256) );
      </pre>
    </div>
    <h3>A function to sort the array by any column</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      function array_compare_factory($sort_key) { 
        return function ($left, $right) <span style="color: yellow;">use ($sort_key)</span> { 
          if ($left[$sort_key] &lt; $right[$sort_key]) {
            return -1; 
          } else if ($left[$sort_key] > $right[$sort_key]) { 
            return 1; 
          } else { 
            return 0; 
          } 
        };
      }
      </pre>
    </div>
    <h3>Code that sorts the array by the name column</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $sort_by_name = array_compare_factory('name'); 
      usort($employees, $sort_by_name);
      </pre>
    </div>
    <h3>Code that sorts the array by the id column</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $sort_by_id = array_compare_factory('id'); 
      usort($employees, $sort_by_id);
      </pre>
    </div>
    <h3>The comparison function with the spaceship operator (PHP 7 and later)</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      function array_compare_factory($sort_key) { 
        return function ($left, $right) use ($sort_key) { 
          return $left[$sort_key] <=> $right[$sort_key]; 
        }; 
      }
      </pre>
    </div>
    <ul>
      <li>A closure is an inner function that has access to the outer function’s variables. To create a closure, code a use clause in the inner function.</li>
      <li>To allow the inner function to change the outer function’s variable, use the refer-ence operator (&) in the use clause.</li>
      <li>The outer function’s variables are available after it has finished executing as long as there is a reference to the inner function.</li>
      <li>The inner function is an anonymous function that is returned by the outer function or stored in a parameter that was passed by reference. You can store it in a variable and call it as a variable function like you would an anonymous function.</li>
    </ul>
    <p><a href=".">Back</a></p>
  </body>
</html>