<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to provide default values for parameters</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />
  </head>
  <body>
    <h1>How to provide default values for parameters</h1>
    <h2>How to assign a default value to a parameter</h2>
    <h3>A function with one default parameter</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <code>
      function get_rand_bool_text($type = 'coin') { <br />
      &nbsp;&nbsp;$rand = random_int(0, 1); <br />
      &nbsp;&nbsp;switch ($type) { <br />
      &nbsp;&nbsp;&nbsp;&nbsp;case 'coin': <br />
      &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;$result = ($rand == 1) ? 'heads' : 'tails';<br />
      &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;break; <br />
      &nbsp;&nbsp;&nbsp;&nbsp;case 'switch':<br />
      &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;$result = ($rand == 1) ? 'on' : 'off'; <br />
      &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;break; <br />
      &nbsp;&nbsp;&nbsp;&nbsp;}<br />
      &nbsp;&nbsp;&nbsp;&nbsp;return $result; <br />
      }<br />
      get_rand_bool_text();<br />
      echo("&lt;p&gt;get_rand_bool_text returns: ". get_rand_bool_text() . "&lt;/p&gt;\n");
      </code>
      <?php
      function get_rand_bool_text($type = 'coin') { 
        $rand = random_int(0, 1); 
        switch ($type) { 
          case 'coin': 
            $result = ($rand == 1) ? 'heads' : 'tails';
            break; 
          case 'switch': $result = ($rand == 1) ? 'on' : 'off'; 
          break; 
        }
        return $result; 
      }
      echo("<p>get_rand_bool_text returns: ". get_rand_bool_text() . "</p>\n");
      ?>
    </div>
    <h3>A function with an optional parameter</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <code>
      function is_leap_year($date = NULL) { <br />
      &nbsp;&nbsp;if (!isset($date)) { <br />
      &nbsp;&nbsp;&nbsp;&nbsp;$date = new DateTime(); <br />
      &nbsp;&nbsp;} <br />
      &nbsp;&nbsp;if ($date->format('L') == '1') {<br />
      &nbsp;&nbsp;&nbsp;&nbsp;return true; <br />
      &nbsp;&nbsp;} else {<br />
      &nbsp;&nbsp;&nbsp;&nbsp;return false; <br />
      &nbsp;&nbsp;}<br />
      }<br />
      echo("&lt;p&gt;Leap year = " . is_leap_year() . "&lt;/p&gt;\n");
      </code>
      <?php
      function is_leap_year($date = NULL) { 
        if (!isset($date)) { 
          $date = new DateTime(); 
        } 
        // echo("<p class='error'>" . $date->format("m/d/y") . "</p>\n");
        if ($date->format('L') == '1') {
          return true;
        } else {
          return false; 
        }
      }
      echo("<p>Leap year = " . is_leap_year() . "</p>\n");
      ?>
    </div>
    <h3>A function with one required and two default parameters</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <code>
      function display_error($error, $tag = 'p', $class = 'error') { <br />
      &nbsp;&nbsp;$opentag = '<' . $tag . ' class="' . $class . '">'; <br />
      &nbsp;&nbsp;$closetag = ''; <br />
      &nbsp;&nbsp;echo $opentag . $error . $closetag; <br />
      }<br />
      display_error("This is an error message!");
      </code>
      <?php
      function display_error($error, $tag = 'p', $class = 'error') { 
        $opentag = '<' . $tag . ' class="' . $class . '">'; 
        $closetag = ''; 
        echo $opentag . $error . $closetag; 
      }
      display_error("This is an error message!");
      ?>
    </div>
    <h2>Calling a function with a default parameter value</h2>
    <h3>Omitting optional parameters</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <code>
      echo get_rand_bool_text(); // Displays 'heads' or 'tails' <br />
      echo display_error('Out of range'); // 'p' tag with 'error' class<br />
      $is_leap_year = is_leap_year(); // true or false based on current date
      </code>
      <?php
      echo get_rand_bool_text(); // Displays 'heads' or 'tails' 
      echo display_error('Out of range'); // 'p' tag with 'error' class
      $is_leap_year = is_leap_year(); // true or false based on current date
      ?>
    </div>
    <h3>Providing optional parameters</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <code>
      echo get_rand_bool_text('switch'); // Displays 'on' or 'off'<br />
      echo display_error('Out of range', 'li');<br />
      <!-- $is_leap_year = is_leap_year(new DateTime('March 15, 2018')); // false<br /> -->
      <!-- echo("&lt;p&gt;Is March 15, 2018 a leap year = $is_leap_year&lt;/p&gt;\n"); -->
      </code>
      <?php
      echo("<p>Switch is " . get_rand_bool_text('switch') . ".</p>\n"); // Displays 'on' or 'off'
      echo("<p>" . display_error('Out of range', 'li') . "</p>\n");
      // $is_leap_year = is_leap_year(new DateTime('March 15, 2018')); // false
      // echo("\$is_leap_year = $is_leap_year</p>\n");
      // echo("</li><p>Is March 15, 2018 a leap year = " . is_leap_year(new DateTime('March 15, 2018')) . ".</p>\n");
      ?>
    </div>    
    <ul>
      <li>To supply a default value for a parameter, code the parameter name followed by the equals sign and the default value. The default value must be a scalar value, an array of scalar values, or NULL. A scalar value is a literal number, string, or Boolean value. A scalar value cannot contain operators, variables, or function calls.</li>
      <li>To code a function that sets a default value for a parameter, assign NULL to the param-eter. Then, within the function, you can check whether the parameter contains NULL. If so, you can write the code that sets the default value for the parameter.</li>
    </ul>
    <p><a href=".">Back</a></p>
  </body>
</html>