<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How variable scope works</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />
  </head>
  <body>
    <h1>How variable scope works</h1>
    <h2>Avariable with global scope</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <code>
      $a = 10; // $a has global scope<br />
      function show_a() {<br />
      &nbsp;&nbsp;echo("&lt;p&gt;Local: $a&lt;/p&gt;\n");  // Inside function, $a is local, and so is not defined (NULL) and displays an error if display_errors are turned on<br />
      }<br />
      show_a(); // Displays nothing
      </code>
      <p></p>
      <?php
      $a = 10; // $a has global scope
      function show_a() {
        echo("<p>$a</p>\n");  // Inside function, $a is local, and so is not defined (NULL) and displays an error if display_errors are turned on
      }
      show_a(); // Displays nothing
      ?>
    </div>
    <h2>How to access a global variable from within a function</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <code>
      $b = 10; // $b has global scope <br />
      function show_b() { <br />
      &nbsp;&nbsp;global $b; // Allow global variable $a to be accessed inside function<br />
      &nbsp;&nbsp;echo("&lt;p&gt;\$b = $b&lt;/p&gt;\n"); <br />
      } <br />
      show_b(); // Displays 10
      </code>
      <?php
      $b = 10; // $b has global scope 
      function show_b() { 
        global $b; // Allow global variable $a to be accessed inside function
        echo("<p>\$b = $b</p>\n"); 
      } 
      show_b(); // Displays 10
      ?>
    </div>
    <h2>Another way to access a global variable from within a function</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <code>
      $c = 10; // $c has global scope <br />
      function show_c() { <br />
      &nbsp;&nbsp;$c = $GLOBALS['c']; // $c now refers to a local variable named $c<br />
      &nbsp;&nbsp;echo("&lt;p&gt;\$c = $c&lt;/p&gt;\n"); <br />
      } <br />
      show_c(); // displays 10
      </code>
      <?php
      $c = 10; // $c has global scope 
      function show_c() { 
        $c = $GLOBALS['c']; // $c now refers to a local variable named $c
        echo("<p>\$c = $c</p>\n"); 
      } 
      show_c(); // displays 10
      ?>
    </div>
    <h2>A variable with local scope function</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <code>
      function show_d() { <br />
      &nbsp;&nbsp;$d = 10; // $d has global scope <br />
      &nbsp;&nbsp;echo("&lt;p&gt;\$d = $d&lt;/p&gt;\n");<br />
      }<br />
      echo("&lt;p&gt;\$d = $d&lt;/p&gt;\n"); // Outside function, $d is local, and so is not defined (NULL) and displays an error if display_errors are turned on<br />
      </code>
      <?php
      function show_d() { 
        $d = 10; // $d has global scope 
        echo("<p>\$d = $d</p>\n");
      }
      show_d();
      echo("<p>\$d = $d</p>\n"); // Outside function, $d is local, and so is not defined (NULL) and displays an error if display_errors are turned on
      ?>
    </div>
    <ul>
      <li>The scope of a variable determines what code can access it. PHP only allows a variable to have a single scope. This means that a variable can only be used where it is defined.</li>
      <li>If a variable is defined inside a function, it has local scope. Then, the variable is only available to code that runs inside that function and is not available outside the function or to any other functions.</li>
      <li>If a variable is defined outside of a function, it has global scope. Then, by default, it is only available to code that runs at the global level and is not available within any functions.</li>
      <li>To access a global variable from within a function, you can use the global statement to import a variable from global scope to local scope.</li>
      <li>To get all variables that are stored in the global scope, you can use the built-in $GLOBALS array. This array is a superglobal variable like the $_POST and $_GET arrays.</li>
    </ul>
    <p><a href=".">Back</a></p>
  </body>
</html>
