<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to work with type declarations</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />
  </head>
  <body>
    <h1>How to work with type declarations</h1>
    <h2>Two functions that use type declarations</h2>
    <h3>A function with one parameter type declaration</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      function display_error(string $error) { 
      &nbsp;&nbsp;echo("&lt;p class='error'&gt;$error&lt;/p&gt;\n");
      }
      </pre>
    </div>
    <h3>A function with type declarations for its parameters and return value</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      function avg_of_3(int $x, int $y, int $z) : float {
      &nbsp;&nbsp;$avg = ($x + $y + $z) / 3;
      &nbsp;&nbsp;return $avg;
      }
      </pre>
    </div>
    <h2>Function calls without strict typing</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      display_error('Value out of range.'); // Displays 'Value out of range.'
      display_error(1); // Displays '1'
      $average = avg_of_3(5, 2, 8); // $average is 5
      $average = avg_of_3(5.1, 2.7, 8.2); // $average is 5
      </pre>
    </div>
    <h2>How to enable strict types mode</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      declare(strict_types=1);  // must be first line of script
      </pre>
    </div>
    <h2>Function calls with strict typing</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      display_error('Value out of range.'); // Displays 'Value out of range.'
      display_error(1); // Fatal error
      $average = avg_of_3(5, 2, 8); // $average is 5
      $average = avg_of_3(5.1, 2.7, 8.2); // Fatal error
      </pre>
    </div>
    <h2>A typical error message when the data type isn’t correct</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       TypeError: Argument 1 passed to avg_of_3() must be of the type integer, float given
      </pre>
    </div>
    <ul>
      <li>With PHP 5, you can declare the type of a parameter for a function and the return type of a function as object types. This includes built-in object types such as the array type as well as user-defined object types such as the Product type described in the next chapter.</li>
      <li>With PHP 7 and later, you can also declare parameter and return types as scalar types such as the int, float, string, and bool types.</li>
      <li>By default, PHP converts a value to the specified type whenever possible.</li>
      <li>If you enable strict types mode and a function receives an argument of an incorrect type, PHP throws an exception.</li>
    </ul>
    <p><a href=".">Back</a></p>
  </body>
</html>