<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to use variable-length parameter lists</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />
  </head>
  <body>
    <h1>How to use variable-length parameter lists</h1>
    <h2>A function that adds a list of numbers</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      function add() {
        $numbers = func_get_args(); 
        $total = 0; 
        foreach($numbers as $number) { 
          $total += $number; 
        } return $total; 
      } $sum = add(5, 10, 15); // $sum is 30
      </pre>
    </div>
    <h2>A function that averages one or more numbers</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      function average($x) { // $x is here to force at least one argument
        $count = func_num_args(); 
        $total = 0; 
        for ($i = 0; $i &lt; $count; $i++) { 
          $total += func_get_arg($i); 
        } 
        return $total / $count;
      }
      $avg = average(75, 95, 100); // $avg is 90
      </pre>
    </div>
    <h2>Using required parameters with a variable parameter list</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      function array_append(&$array, $x) {
        $values = func_get_args();
        array_shift($values); 
        foreach($values as $value) { 
          $array[] = $value;
        } 
      } 
      $data = array('apples', 'oranges'); 
      array_append($data, 'grapes', 'pears');
      </pre>
    </div>
    <ul>
      <li>A variable-length parameter list lets you create a function that works with a variable number of arguments.</li>
      <li>You can require a minimum number of arguments by using placeholder parameters in the parameter list.</li>
    </ul>
    <p><a href=".">Back</a></p>
  </body>
</html>