<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to create abstract classes and methods</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to create abstract classes and methods</h1>
    <h2>An abstract class with an abstract method</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      abstract class Person { 
        private $firstName, $lastName, $phone, $email;

        // The constructor and the get and set methods are the same as the Person class

        // An abstract method 
        abstract public function getFullName();
      }
      </pre>
    </div>
    <h2>A concrete class that implements an abstract class</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      class Customer extends Person {
        private $cardNumber, $cardType;

        public function __construct($first, $last, $phone, $email) {
          $this->setPhone($phone);
          $this->setEmail($email);
          parent::__construct($first, $last);
        } 
        
        public function getCardNumber() {
          return $this->cardNumber; 
        } 
        
        public function setCardNumber($value) {
          $this->cardNumber = $value; 
        } 
        
        public function getCardType() {
          return $this->cardType; 
        }
        
        public function setCardType($value) { 
          $this->cardType = $value; 
        } 
        
        // Concrete implementation of the abstract method 
        public function getFullName() {
          return $this->getFirstName() . ' ' . $this->getLastName(); 
        } 
      }
      </pre>
    </div>
    <h2>Code that attempts to create an object from the abstract class</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $customer = new Person('John', 'Doe'); // Fatal error
      </pre>
    </div>
    <h2>Code that creates and uses an object from the concrete</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       class $customer = new Customer('John', 'Doe', '919-555-4321', 'jdoe@example.com');
       echo("&lt;p&gt;" .$customer->getFullName() . "&lt;/p&gt;");
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>An abstract class is a class that can’t be used to create an object. It’s useful as a superclass for other classes.</li>
        <li>An abstract method is a method that specifies the name and parameters for the method but doesn’t provide a code block that implements the method.</li>
        <li>An abstract method can only be coded in an abstract class. However, an abstract class isn’t required to have an abstract method.</li>
        <li>A concrete class is a class that can be used to create an object. A concrete subclass of an abstract class must provide an implementation for all abstract methods in the abstract class. Otherwise, PHP issues a fatal error.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>