<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to clone and compare objects</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to clone and compare objects</h1>
    <h2>How to clone an object</h2>
    <h3>The syntax</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      clone <em>$objectName</em>
      </pre>
    </div>
    <h3>An object to clone</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $brass = new Category(4, 'Brass'); 
      $trumpet = new Product($brass, 'Getzen', 'Getzen 700SP Trumpet', 999.95);
      </pre>
    </div>
    <h3>Create a second reference to an object</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $trombone = $trumpet; 
      $trombone->setPrice(699.95);
      </pre>
    </div>
    <h3>Create a clone of an object</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $trombone = clone $trumpet; 
      $trombone->setPrice(899.95);
      </pre>
    </div>
    <h3>The copies are shallow copies</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $trombone->getCategory()->setName('Orchestral Brass'); 
      echo $trumpet->getCategory()->getName(); // Displays 'Orchestral Brass'
      </pre>
    </div>
    <h2>How to compare two objects</h2>
    <h3>Use the equality (==) operator</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $result_1 = ($trumpet == $trombone); // $result_1 is FALSE
      
      $flugelhorn = clone $trumpet; 
      $result_2 = ($trumpet == $flugelhorn); // $result_2 is TRUE
      </pre>
    </div>
    <h3>Use the identity (===) operator</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       $result_3 = ($trumpet === $flugelhorn); // $result_3 is FALSE 
       
       $trumpet_2 = $trumpet;
       $result_4 = ($trumpet === $trumpet_2); // $result_4 is TRUE 
       
       $result_5 = ($trumpet->getCategory() === $trombone->getCategory()); // $result_5 is TRUE
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>To create a second reference to an object, you can use the equals (=) operator. To create a copy, or clone, of an object, you must use the clone operator.</li>
        <li>When you create a copy of an object, PHP makes a shallow copy of the object. This means that PHP doesn’t create copies of nested objects within the original object.</li>
        <li>You can use the equality operator (==) to check whether both objects are instances of the same class and have the same values for every property.</li>
        <li>You can use the identity operator (===) to check whether both object variables refer to the same instance of an object.</li>
        <li>You can also use the logical not versions of the equality (!=) and identity (!==) operators.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>