<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to code constructors and destructors</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to code constructors and destructors</h1>
    <h2>How to code a constructor method</h2>
    <h3>The syntax</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      public function __construct([parameterList]) { 
        // Statements to execute 
      }
      </pre>
    </div>
    <h3>The default constructor</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      public function __construct() { }
      </pre>
    </div>
    <h3>The constructor for the Category class</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      public function <span style="background-color: yellow;">__</span>construct($id, $name) { 
        $this->id = $id; 
        $this->name = $name; 
      }
      </pre>
    </div>
    <h3>The constructor for the Category class with default values</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      public function __construct($id = NULL, $name = NULL) { 
        $this->id = $id; 
        $this->name = $name; 
      }
      </pre>
    </div>
    <h2>How to code a destructor method</h2>
    <h3>The syntax</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      public function __destruct() { 
        // Statements to execute 
      } 
      </pre>
    </div>
    <h3>A destructor for a database class</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      public function __destruct() { 
        $this->dbConnection->close();
      }
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>A constructor method, or just constructor, is a special method that’s executed when a new object is created from the class. It often initializes the properties of the object</li>
        <li>A destructor method, or just destructor, is a special method that’s executed when an object is no longer available for use. In other words, it is executed when there are no variables that refer to the object. This type of method can’t include any parameters.</li>
        <li>Within a class, the special variable named $this stores a reference to the current object. As a result, it allows you to access the properties and methods of the current object.</li>
        <li>The object access operator (->) provides access to an object’s properties and methods. When you code the object access operator, you can’t have a space between the two characters.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>
