<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to create final classes and methods</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to create final classes and methods</h1>
    <h2>How to prevent a method from being overridden</h2>
    <h3>A class with a final method</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      class Person {
        // Other properties and methods not shown here 
        
        final public function getFirstName() {
          return $this->firstName; 
        } 
      }
      </pre>
    </div>
    <h3>A subclass that attempts to override a final method leading to a fatal error</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      class Employee extends Person {
        // Other properties and methods not shown here

        // This method attempts to override a final method - fatal error 
        public function getFirstName() {
          return ucwords($this->firstName); 
        } 
      }
      </pre>
    </div>
    <h2>How to prevent a class from being inherited</h2>
    <h3>A final class</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      final class Employee extends Person {
        // Properties and methods for class 
      }
      </pre>
    </div>
    <h3>A class that attempts to inherit a final class leading to a fatal error</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      class PartTime extends Employee {
        // Properties and methods for class 
      }
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>A final method cannot be overridden by a method in a subclass. As a result, all subclasses must use the final version of the method.</li>
        <li>A final class cannot be inherited by a subclass.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>