<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to work with interfaces</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to work with interfaces</h1>
    <h2>How to create an interface</h2>
    <h3>The syntax</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      interface interfaceName {
        const constantName = constantValue;
        public function methodName( parameterList ); 
      } 
      </pre>
    </div>
    <h3>An interface to show an object</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      interface Showable {
        public function show(); 
      }
      </pre>
    </div>
    <h3>An interface to require two test methods</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      interface Testable {
        public function test1($value1);
        public function test2($value1, $value2); }
      </pre>
    </div>
    <h3>An interface that provides three constants</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      interface EyeColor {
        const GREEN = 1;
        const BLUE = 2;
        const BROWN = 3; 
      }
      </pre>
    </div>
    <h2>A class that inherits a class and implements an interface</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      class Employee extends Person implements Showable {
        // The constructor and the get and set methods are the same as the Person class

        Implement the Showable interface 
        public function show() { 
          echo("First Name:" . $this->getFirstName() . "&lt;br /&gt;");
          echo("Last Name: " . $this->getLastName() . "&lt;br /&gt;");
          echo("SSN: " . $this->ssn . "&lt;br /&gt;");
          echo 'Hire Date: ' . $this->hireDate . '"&lt;br /&gt;");
        }
      }
      </pre>
    </div>
    <h2>A class declaration that implements three interfaces</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      class Customer extends Person implements Showable, Testable, EyeColor {
        // class code here
      }
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>An interface defines a set of public methods that can be implemented by a class. The interface doesn’t provide any code to implement the methods, but it provides the method names and parameter lists.</li>
        <li>All methods in an interface must be public and cannot be static.</li>
        <li>A class that implements an interface must provide an implementation for each method defined by the interface.</li>
        <li>An interface can define class constants that are available to any class that imple-ments the interface.</li>
        <li>Although a class can only inherit one class, it can implement multiple interfaces.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>