<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to loop through an object’s properties</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to loop through an object’s properties</h1>
    <h2>The syntax</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      foreach($objectName as [ $propertyName => ] $propertyValue) {
        // statements to execute 
      }
      </pre>
    </div>
    <h2>Define an Employee class</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      class Employee {
        public $firstName, $lastName; 
        private $ssn, $dob;
        public function __construct($first, $last) { 
          $this->firstName = $first; 
          $this->lastName = $last; 
        } 
        
        // getSSN, setSSN, getDOB, setDOB methods not shown 
        
        // Show all properties – private, protected, and public public 
        function showAll() { 
          echo("&lt;ul&gt;\n");
          foreach($this as $name => $value ) {
            echo("&lt;li&gt;$name = $value&lt;/li&gt;\n");
          }
          echo("&lt;/ul&gt;\n");
        } 
      }
      </pre>
    </div>
    <h2>Create an Employee object with four properties</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $employee = new Employee('John', 'Doe'); 
      $employee->setSSN('999-14-3456'); 
      $employee->setDOB('3-15-1970');
      </pre>
    </div>
    <h2>Show all properties</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $employee->showAll();
      </pre>
    </div>
    <h2>Show public properties only</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      echo("&lt;ul&gt;\n");
      foreach($employee as $name => $value ) { 
        echo("&lt;li&gt;$name = $value&lt;/li&gt;\n");
      }
      echo("&lt;/ul&gt;\n");
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>You can use a <code>foreach</code> loop to access each property in an object.</li>
        <li>A <code>foreach</code> loop coded inside a method of an object loops through the object’s private, protected, and public properties.</li>
        <li>A <code>foreach</code> loop coded outside an object only loops through the object’s public properties.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>