<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to code methods</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to code methods</h1>
    <h2>The syntax</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      [public | private | protected] function functionName ([parameterList]) { 
        // Statements to execute 
      }
      </pre>
    </div>
    <h2>A public method</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      public function getSummary() { 
        $maxLength = 25; 
        $summary = $this->description; 
        if (strlen($summary) > $maxLength) { 
          $summary = substr($summary, 0, $maxLength - 3) . '...'; 
        }
        return $summary
      }
      </pre>
    </div>
    <h2>A private method</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      private function internationalizePrice($country = 'US') {
        switch ($country) {
          case 'US':
            return '$' . number_format($this->price, 2); 
          case 'FR': 
            return number_format($this->price, 2, ',' , '.') . ' EUR'; 
          default: 
            return number_format($this->price, 2); 
        } 
      }
      </pre>
    </div>
    <h2>A method that accesses a property of the current object</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      public function showDescription() {
        echo $this->description;
      }
      </pre>
    </div>
    <h2>A method that calls a method of the current object</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      public function showPrice($country = 'US') {
        echo $this->internationalizePrice($country);
      }
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>To code a method in a class, you code one of the access modifier keywords followed by the function keyword, the name of the method, an optional parameter list in a set of parentheses, and a block of code to execute.</li>
        <li>By default, methods are public. As a result, if you omit the access modifier, the method is public. However, to make your code more consistent and readable, it’s generally considered a good practice to code an access modifier for all methods.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>