<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to create and use objects</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to create and use objects</h1>
    <h2>How to create an object</h2>
    <h3>The syntax</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $objectName = new ClassName(argumentList);
      </pre>
    </div>
    <h3>Create a Category</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      object $brass = new Category(4, 'Brass');
      </pre>
    </div>
    <h3>Create a Product object</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $trumpet = new Product($brass, 'Getzen', 'Getzen 700SP Trumpet', 999.95);
      </pre>
    </div>
    <h2>How to access an object’s properties</h2>
    <h3>The syntax for setting a public property value</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $objectName->propertyName = value; 
      </pre>
    </div>
    <h3>The syntax for getting a public property value</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $objectName->propertyName;
      </pre>
    </div>
    <h3>Set a property</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $trumpet->comment = 'Discontinued';
      </pre>
    </div>
    <h3>Get a property</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      echo $trumpet->comment;
      </pre>
    </div>
    <h2>How to call an object’s methods</h2>
    <h3>The syntax</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $objectName->methodName(argumentList);
      </pre>
    </div>
    <h3>Call the getFormattedPrice() method</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $price = $trumpet->getFormattedPrice();
      </pre>
    </div>
    <h3>Object chaining</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      echo $trumpet->getCategory()->getName();
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>An object is an instance of a class. In other words, you can create more than one object from a single class. The process of creating an object from a class is sometimes called <em>instantiation</em>.</li>
        <li>To create an object, you code the new keyword followed by the name of the class and a set of parentheses. Inside the parentheses, you code the arguments for the constructor separated by commas.</li>
        <li>To access an object’s property, you code a reference to the object followed by the object access operator (-&gt;) and the name of the property.</li>
        <li>To call an object’s method, you code a reference to the object followed by the object access operator (-&gt;), the name of the method, and a set of parentheses. Inside the parentheses, you code the arguments for the method separated by commas.</li>
        <li>If a function or method returns an object, you can use the function or method call as a reference to the object and continue accessing the returned object’s properties and methods. This is called <em>object chaining</em>.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>