<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to code static properties and methods</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to create static properties and methods</h1>
    <h2>A class with a private static property and a public static method</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      class Category {
        private $id, $name;
        private <span style="background-color: yellow;">static</span> $objectCount = 0; // declare a static property
        public function __construct($id, $name) {
          $this->id = $id;
          $this->name = $name;
          <span style="background-color: yellow;">self</span>::$objectCount++; // update the static property
        }
        
        // A public method that gets the static property
        public static function getObjectCount(){
          return self::$objectCount;
        }

        // The rest of the methods for the Category class
      } 
      </pre>
    </div>
    <h2>How to use a public static method from outside a class</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $guitars = new Category(1, 'Guitars');
      $basses = new Category(2, 'Basses');
      echo("&lt;p&gt; Object count: " . Category::getObjectCount() . "&lt;/p&gt;); // 2 
      $drums = new Category(3, 'Drums');
      echo("&lt;p&gt; Object count: " . Category::getObjectCount() . "&lt;/p&gt;); // 3
      </pre>
    </div>
    <h2>How to use a public static property from outside a class</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      echo("&lt;p&gt; Object count: $objectCount&lt;/p&gt;);
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>A static property or static method is a property or method that belongs to a class, not to objects created from the class. You use the static keyword to create these types of properties and methods, which are also referred to as class properties and class methods.</li>
        <li>Inside a class, you can access a static property or method by coding the self keyword followed by a double colon and the property or method name.</li>
        <li>Outside a class, you can access a static property or method that’s public by coding the class name followed by a double colon and the static property or method name.</li>
        <li>When you access a static property, you must include the dollar sign at the begin-ning of the property’s name.</li>
        <li>In a PHP application, the code space is separate for each user, which means that each user runs its own copy of the code. As a result, static properties and methods aren’t shared between multiple users.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>
