<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to use look-ahead assertions</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to use look-ahead assertions</h1>
    <h2>How to match assertions</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Pattern</th>
            <th>Meaning</th>
          </tr>
        </thead>
          <tr>
            <td>(?=assertion)</td>
            <td>Creates a look-ahead assertion</td>
          </tr>
          <tr>
            <td>(?!assertion)</td>
            <td>Creates a negative look-ahead assertion</td>
          </tr>
        <tbody>
        </tbody>
      </table>
    </div>
    <h2>Two subpatterns for look-ahead assertions</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      (?=[[:digit:]])  // Assertion fails and returns 0
      (?=.*[[:digit:]]) // Matches and returns 1
      </pre>
    </div>
    <h2>How to create a look-ahead assertion</h2>
    <h3>A look-ahead assertion</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
        $pattern = '/^(?=.*[[:digit:]])[[:alnum:]]{6}$/'; 
        preg_match($pattern, 'Harris'); // Assertion fails and returns 0
        preg_match($pattern, 'Harri5'); // Matches and returns 1
      </pre>
    </div>
    <h3>A negative look-ahead assertion</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $pattern = '/^(?!3[2-9])[0-3][[:digit:]]$/'; 
      preg_match($pattern, '32'); // Assertion fails and returns 0
      preg_match($pattern, '31'); // Matches and returns 1
      </pre>
    </div>
    <h2>A pattern to enforce password complexity</h2>
    <h3>The full pattern</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $pw_pattern = '/^(?=.*[[:digit:]])(?=.*[[:punct:]])[[:print:]]{6,}$/'; 
      </pre>
    </div>
    <h3>The parts of the pattern</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       ^  // From the start of the string
       (?=.*[[:digit:]])  // Must contain at least one digit
       (?=.*[[:punct:]]) // Must contain at least one punctuation character
       [[:print:]]{6,}  // Must contain six or more printable characters
       $ // With nothing else until the end of the string
      </pre>
    </div>
    <h3>Using the pattern</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $password1 = 'sup3rsecret'; 
      $password2 = 'sup3rse(ret'; 
      preg_match($pw_pattern, $password1); // Assertion fails and returns 0
      preg_match($pw_pattern, $password2); // Matches and returns 1
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>A look-ahead assertion is a special type of subpattern that must be matched for the overall pattern to be matched.</li>
        <li>A look-ahead assertion must be matched starting immediately after the position of the assertion in the pattern.</li>
        <li>A negative look-ahead assertion is similar to a look-ahead assertion except that its pattern must not be matched.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>