<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to use the  character class</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />
    <style>
      table, th, td {
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to use the  character class</h1>
    <h2>The character class</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       $string = 'The product code is MBT-3461.'; 
       preg_match('/MB[TF]/', $string); // Matches MBT and returns 1
       preg_match('/[.]/', $string); // Matches . and returns 1
       preg_match('/[13579]/', $string); // Matches 3 and returns 1
      </pre>
    </div>
    <h2>Metacharacters inside a character class</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: 1em;">
      <table>
        <thead>
          <tr>
            <th>Character</th>
            <th>Example</th>
            <th>Meaning</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>^</td>
            <td>[^aeiou]</td>
            <td>Negates the list of characters inside the character class</td>
          </tr>
          <tr>
            <td>-</td>
            <td>[a-z]</td>
            <td>Creates a range of characters based on their Latin-1 character set values</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>Metacharacters</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      preg_match('/MB[^TF]/', $string); // Matches nothing and returns 0
      preg_match('/MBT[^^]/', $string); // Matches MBT- and returns 1
      preg_match('/MBT-[1-5]/', $string); // Matches MBT-3 and returns 1
      preg_match('/MBT[_*-]/', $string)  // Matches MBT- and returns 1
      </pre>
    </div>
    <h2>How to use bracket expressions in a character class</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <table style="font-size: 2em;">
        <thead>
          <tr>
            <th>Pattern</th>
            <th>Matches</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>[:digit:]</td>
            <td>Digits (same as \d)</td>
          </tr>
          <tr>
          <tr>
            <td>[:lower:]</td>
            <td>Lowercase letters</td>
          </tr>
          <tr>
          <tr>
            <td>[:upper:]</td>
            <td>Uppercase letters</td>
          </tr>
          <tr>
          <tr>
            <td>[:letter:]</td>
            <td>Upper-and lowercase letters</td>
          </tr>
          <tr>
          <tr>
            <td>[:alnum:]</td>
            <td>Upper-and lowercase letters and digits</td>
          </tr>
          <tr>
          <tr>
            <td>[:word:]</td>
            <td>Upper-and lowercase letters, digits, and the underscores (same as \w)</td>
          </tr>
          <tr>
          <tr>
            <td>[:print:]</td>
            <td>All printable characters including the space</td>
          </tr>
          <tr>
          <tr>
            <td>[:graph:]</td>
            <td>All printable characters excluding the spacet</td>
          </tr>
          <tr>
          <tr>
            <td>[:punct:]</td>
            <td>All printable characters excluding letters and digits</td>
          </tr>
          <tr>
      </table>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>A character class lets you match a single character from a list of possible characters.</li>
        <li>Most characters with a special meaning lose it inside the brackets. The caret and dash are the only characters that retain their special meanings, and they are position dependent.</li>
        <li>You can use a bracket expression inside a character class for several predefined character ranges, and you can combine several bracket expressions in one character class.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>