<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to create complex patterns</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif; 
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to create complex patterns</h1>
    <h2>HOw to match string positions</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Pattern</th>
            <th>Matches</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>^</td>
            <td>The beginning of the string (use \^ to match a caret)</td>
          </tr>
          <tr>
            <td>$</td>
            <td>The end of the string (use \$ to match a dollar sign)</td>
          </tr>
          <tr>
            <td>\b</td>
            <td>The beginning or end of a word (must not be inside brackets)</td>
          </tr>
          <tr>
            <td>\B</td>
            <td>A position other than the beginning or end of a word</td>
          </tr>
        </tbody>      
      </table>
    </div>
    <h2>String positions</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $author = 'Ray Harris'; 
      preg_match('/^Ray/', $author); // Returns 1
      preg_match('/Harris$/', $author); // Returns 1
      preg_match('/^Harris/', $author); // Returns 0
      $editor = 'Anne Boehm';
      preg_match('/Ann/', $editor); // Returns 1
      preg_match('/Ann\b/', $editor);  // Returns 0
      </pre>
    </div>
    <h2>How to group and match subpatterns</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Pattern</th>
            <th>Matches</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>(subpattern)</td>
            <td>Creates a numbered subpattern group (use \( and \) to match a parenthesis)</td>
          </tr>
          <tr>
            <td>(?:subpattern)</td>
            <td>Creates an unnumbered subpattern group</td>
          </tr>
          <tr>
            <td>|</td>
            <td>Matches either the left or right subpattern</td>
          </tr>
          <tr>
            <td>\n</td>
            <td>Matches a numbered subpattern group</td>
          </tr>
        </tbody>      
      </table>    
    </div>
    <h2></h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Pattern</th>
            <th>Matches</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>^</td>
            <td>The beginning of the string (use \^ to match a caret)</td>
          </tr>
          <tr>
            <td>$</td>
            <td>The end of the string (use \$ to match a dollar sign)</td>
          </tr>
          <tr>
            <td>\b</td>
            <td>The beginning or end of a word (must not be inside brackets)</td>
          </tr>
          <tr>
            <td>\B</td>
            <td>A position other than the beginning or end of a word</td>
          </tr>
        </tbody>      
      </table>    
    </div>
    <h2>Subpatterns</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $name = 'Rob Robertson'; 
      preg_match('/^(Rob)|(Bob)\b/', $name); // Returns 1
      preg_match('/^(\w\w\w) \1/', $name); // Returns 1
      </pre>
    </div>
    <h2>How to match a repeating pattern</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Pattern</th>
            <th>Matches</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>{n}</td>
            <td>Pattern must repeat exactly n times (use \{ and \} to match a brace)</td>
          </tr>
          <tr>
            <td>{n,}</td>
            <td>Pattern must repeat n or more times</td>
          </tr>
          <tr>
            <td>{n,m}</td>
            <td>Subpattern must repeat from n to m times Zero or one of the previous subpattern (same as {0,1})</td>
          </tr>
          <tr>
            <td>+</td>
            <td>One or more of the previous subpattern (same as {1,})</td>
          </tr>
          <tr>
            <td>*</td>
            <td>Zero or more of the previous subpattern (same as {0,})</td>
          </tr>
        </tbody>      
      </table>    
    </div>
    <h2>Repeating patterns</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $phone = '559-555-6627'; 
      preg_match('/^\d{3}-\d{3}-\d{4}$/', $phone); // Returns 1
      $fax = '(559) 555-6635'; 
      preg_match('/^\(\d{3}\) ?\d{3}-\d{4}$/', $fax); // Returns 1
      preg_match($phone_pattern, $fax); // Returns 1
      $phone_pattern = '/^(\d{3}-)|(\(\d{3}\) ?)\d{3}-\d{4}$/';
      preg_match($phone_pattern, $phone) // Returns 1
      </pre>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>
 