<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to match characters</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />
    <style>
      table, th, td {
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to match characters</h1>
    <h2>How to match special characters</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Pattern</th>
            <th>Matches</th>
          </tr>
          <tr>
            <td>\\</td>
            <td>Backslash character</td>
          </tr>
            <td>\/</td>
            <td>Forward slash</td>
          </tr>
          <tr>
            <td>\t</td>
            <td>Tab</td>
          </tr>
          <tr>
            <td>\n</td>
            <td>New Line</td>
          </tr>
          <tr>
            <td>\r</td>
            <td>Carriage Return</td>
          </tr>
          <tr>
            <td>\f</td>
            <td>Form Feed</td>
          </tr>
          <tr>
            <td>\xhh</td>
            <td>The Latin-1 character whose value is the two hexadecimal digits</td>
          </tr>
        </table>
    </div>
    <h2>Special characters</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $string = "© 2017 Mike's Music. \ All rights reserved (5/2017).";
      preg_match('/\xA9/', $string); // Matches © and returns 1
      preg_match('///', $string); // Returns FALSE and issues a warning
      preg_match('/\//', $string); // Matches / and returns 1
      preg_match('/\\\\/', $string); // Matches \ and returns 1
      </pre>
    </div>
    <h2>How to match types of characters</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <table>
        <thead>
          <tr>
            <th>Pattern</th>
            <th>Matches</th>
          </tr>
          <tr>
            <td>.</td>
            <td>Any single character except a new line character (use \. to match a period)</td>
          </tr>
            <td>\w</td>
            <td>Any letter, number, or the underscore</td>
          </tr>
          <tr>
            <td>\W</td>
            <td>Any character that’s not a letter, number, or the underscore</td>
          </tr>
          <tr>
            <td>\d</td>
            <td>Any digit</td>
          </tr>
          <tr>
            <td>\D</td>
            <td>Any character that’s not a digit</td>
          </tr>
          <tr>
            <td>\s</td>
            <td>Any whitespace character (space, tab, new line, carriage return, form feed, or vertical tab)</td>
          </tr>
          <tr>
            <td>\S</td>
            <td>Any character that’s not whitespace</td>
          </tr>
        </table>
    </div>
    <h2>Types of characters</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $string = 'The product code is MBT-3461.'; 
      preg_match('/MB./', $string); // Matches MBT and returns 1
      preg_match('/MB\d/', $string); // Matches nothing and returns 0
      preg_match('/MBT-\d/', $string); // Matches MBT-3 and returns 1
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>The backslash is the escape character in regular expressions. It gives special meaning to some characters and removes the special meaning from others.</li>
        <li>Since the backslash is the escape character in patterns, any backslash in your pattern must be preceded by another backslash. Then, since the backslash is also the escape character in PHP strings, each backslash must be preceded by another backslash.</li>
        <li>When a character has a special meaning in a pattern, it’s called a metacharacter.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>