<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to work with tables</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to work with tables</h1>
    <h2>An introduction to MySQL data types</h2>
    <h3>Common numeric data types</h3>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Type</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>INT[(size)]</td>
            <td>An integer between -2,147,483,648 and 2,147,483,647 where size is the maximum display size. Default size is 11.</td>
          </tr>
          <tr>
            <td>TINYINT[(size)]</td>
            <td>An integer between -127 and 128 where size is the maximum display size. Default size is 4.</td>
          </tr>
          <tr>
            <td>DECIMAL[(p[,s])]</td>
            <td>Decimal numbers with fixed precision (p) and scale (s). The maximum precision is 65 and the default is 10. The maximum scale is 30 and the default is 0.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h3>Common string data types</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Type</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>VARCHAR[(size)]</td>
            <td>Variable-length characters where size is the maximum number of characters. The size argument is required. The maximum size is 65,535.</td>
          </tr>
          <tr>
            <td>CHAR(size)</td>
            <td>Fixed-length characters where size is the number of characters. The default size is 1. The maximum size is 255. </td>
          </tr>
          <tr>
            <td>TEXT</td>
            <td>Variable-length characters up to a maximum size of 65,535 bytes.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h3>Common date and time data types</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead
>          <tr>
            <th>Type</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>DATE</td>
            <td>Dates from January 1, 1000 through December 31, 9999. The default format for entry and display is "yyyy-mm-dd". </td>
          </tr>
          <tr>
            <td>TIME</td>
            <td>Times in the range -838:59:59 through 838:59:59. The default format for display and entry is "hh:mi:ss".</td>
          </tr>
          <tr>
            <td>DATETIME</td>
            <td>Date and time from January 1, 1970 through December 31, 9999. The default format for display and entry is "yyyy-mm-dd hh:mi:ss".</td>
          </tr>
        </tbody>
      </table>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>By default, MySQL uses the <span style="background-color: yellow;">Latin-1</span> character set, which provides for 256 charac-ters with 1 byte per character.</li>
        <li>The <span style="background-color: yellow;">Unicode character set</span> provides for over 65,000 characters, usually with 2 bytes per character.</li>
        <li>The CHAR data type is typically used for <span style="background-color: yellow;">fixed-length strings</span>. This data type uses the same amount of storage regardless of the actual length of the string. If you insert a value that’s shorter than the specified type, the end of the value will be padded with spaces.</li>
        <li>The VARCHAR data type is typically used for <span style="background-color: yellow;">variable-length strings</span>. This data type uses only the amount of storage needed for a given string.</li>
        <li>The <span style="background-color: yellow;">precision</span> of a DECIMAL type indicates the total number of digits that can be stored in the data type. The <span style="background-color: yellow;">scale</span> indicates the number of decimal digits that can be stored to the right of the decimal point. The decimal point and minus sign for the number aren’t counted in the precision.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>