<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to create a table</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to create a table</h1>
    <h2>The syntax of the <code>CREATE TABLE</code> statement</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      CREATE TABLE [IF NOT EXISTS] tableName 
                   ( columnName1 dataType [columnAttributes]
                   [, columnName2 dataType [columnAttributes]]
                   [, columnName3 dataType [columnAttributes]]... 
                   )
      </pre>
    </div>
    <h2>Three common column attributes</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Attribute</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>UNIQUE</td>
            <td>Specifies that each value stored in the column must be unique, but allows the column to store NULL values.</td>
          </tr>
          <tr>
            <td>NOT NULLL</td>
            <td>Indicates that the column doesn’t accept NULL values. If omitted, the column can accept NULL values.</td>
          </tr>
          <tr>
            <td>DEFAULT default_value</td>
            <td>Specifies a default value for the column.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>A table without column attributes</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      CREATE TABLE customers ( 
        customerID INT,
        firstName VARCHAR(60),
        lastName VARCHAR(60)
      );
      </pre>
    </div>
    <h2>A table with column attributes</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      CREATE TABLE customers (
        customerID INT NOT NULL UNIQUE,
        firstName VARCHAR(60) NOT NULL,
        lastName VARCHAR(60) NOT NULL
      );
      </pre>
    </div>
    <h2>Another table with column attributes</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      CREATE TABLE orders (
        orderID  INT NOT NULL UNIQUE,
        customerID INT NOT NULL UNIQUE,
        orderNumber VARCHAR(50) NOT NULL,
        orderDate DATE NOT NULL,
        orderTotal DECIMAL(9,2) NOT NULL,
        paymentTotal DECIMAL(9,2) DEFAULT 0
      );
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>The <code>CREATE TABLE</code> statement creates a table based on the column definitions and column attributes you specify.</li>
        <li>Since the <code>NOT NULL</code> and <code>UNIQUE</code> attributes limit the type of data that a column can store, they are known as constraints.</li>
        <li>To review the complete syntax of the <code>CREATE TABLE</code> statement, you can search the MySQL Reference Manual, which is available online.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>