<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to code a foreign key constraint</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to code a foreign key constraint</h1>
    <h2>Three attributes for working with a foreign key</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Attribute</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>CONSTRAINT</td>
            <td>The name of the constraint. Can only be coded at the table level.</td>
          </tr>
          <tr>
            <td>FOREIGN KEY</td>
            <td>The names of the columns that make up the foreign key. Can only be coded at the table level.</td>
          </tr>
          <tr>
            <td>REFERENCES</td>
            <td>The name of the related table and the column or columns. Can be coded at the column or table level. When coded at the column level, it can only refer to a single column.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>A table with a column-level foreign key constraint</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       CREATE TABLE orders ( 
         orderID PRIMARY KEY,
         customerID NOT NULL
                    REFERENCES customers (customerID),
         orderDate  NOT NULL
       )
      </pre>
    </div>
    <h2>A table with a table-level foreign key constraint</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      CREATE TABLE orders (
        orderID INT PRIMARY KEY,
        customerID INT  NOT NULL,
        orderDate DATETIME  NOT NULL,
        CONSTRAINT 
          ordersFkCustomers FOREIGN KEY (customerID)
          REFERENCES customers (customerID)
      )
      </pre>
    </div>
    <h2>An INSERT statement that fails because a related row doesn’t exist</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      INSERT INTO orders 
      VALUES (1, 999, '2017-08-03');
      </pre>
      <h3>The response from the system</h3>
      <pre>
      Error Code: 1452.
      
      Cannot add or update a child row: a foreign key con-straint fails ('ex'.'orders', CONSTRAINT 'ordersFkCustomers' FOREIGN KEY ('customerID') REFERENCES 'customers' ('customerID'))
      </pre>
    </div>
    <h2>A constraint that uses the ON DELETE clause</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      CONSTRAINT ordersFkCustomers 
        FOREIGN KEY (customerID) REFERENCES customers (customerID) 
        ON DELETE CASCADE
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>A foreign key constraint requires values in one table to match values in another table. This defines the relationship between two tables and enforces referential integrity.</li>
        <li>To define a relationship that consists of two or more columns, you must define the constraint at the table level.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>