<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to grant privileges</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to grant privileges</h1>
    <h2>The syntax of the <code>GRANT</code> statement</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <pre>
      GRANT privilegeList ON [dbName.]table 
      TO userName1 [IDENTIFIED BY 'password1'][, userName2 [IDENTIFIED BY 'password2']...] [WITH GRANT OPTION
      </pre>
    </div>
    <h2>A statement that creates a user with no privileges</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      GRANT USAGE ON *.* TO joel@localhost IDENTIFIED BY 'sesame';
      </pre>
    </div>
    <h2>A statement that creates a user with database privileges</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      GRANT SELECT, INSERT, UPDATE, DELETE ON my_guitar_shop2.* 
      TO mgs_user@localhost IDENTIFIED BY 'pa55word';
      </pre>
    </div>
    <h2>A statement that creates a user with global privileges</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      GRANT ALL ON *.* TO dba IDENTIFIED BY 'supersecret' WITH GRANT OPTION;
      </pre>
    </div>
    <h2>A statement that grants table privileges to a user</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      GRANT SELECT, INSERT, UPDATE ON my_guitar_shop2.products TO joel@localhost;
      </pre>
    </div>
    <h2>A statement that grants database privileges to a user</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      GRANT SELECT, INSERT, UPDATE ON my_guitar_shop2.* TO joel@localhost; 
      </pre>
    </div>
    <h2>A statement that grants global privileges to a user</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      GRANT SELECT, INSERT, UPDATE ON *.* TO joel@localhost;
      </pre>
    </div>
    <h2>A statement that grants column privileges to a user</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      GRANT SELECT (productCode, productName, listPrice), UPDATE (description) ON my_guitar_shop2.products TO joel@localhost;
      </pre>
    </div>
    <h2>A statement that uses the current database</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      GRANT SELECT, INSERT, UPDATE, DELETE ON customers TO joel@localhost;
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>The <code>WITH GRANT OPTION</code> clause allows the user to grant the privileges for that user to other users.You can use the asterisk (*) to specify all databases or all tables.</li>
        <li>You can use the asterisk (*) to specify all databases or all tables.</li>
        <li>If you don’t specify a database, MySQL uses the current database.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>