<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to work with indexes</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to create an index</h1>
    <h2>The syntax of the CREATE INDEX statement</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <pre>
       CREATE [UNIQUE] INDEX|KEY indexName ON tableName (columnName1 [ASC|DESC] [, columnName2 [ASC|DESC]]...)
      </pre>
    </div>
    <h3>A statement that creates an index based on a single column></h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      CREATE INDEX customerID ON orders (customerID);
      </pre>
    </div>
    <h3>A statement that creates a unique index</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      CREATE UNIQUE INDEX emailAddress ON customers (emailAddress);
      </pre>
    </div>
    <h3>A statement that creates an index based on two columns</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      CREATE UNIQUE INDEX customerIDorderNumber ON orders (customerID, orderNumber);
      </pre>
    </div>
    <h3>A statement that creates an index that’s sorted in descending order</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      CREATE INDEX orderTotal ON orders (orderTotal DESC);
      </pre>
    </div>
    <h2>A <code>CREATE TABLE</code> statement that also creates indexes</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      CREATE TABLE customers (
        customerID INT NOT NULL AUTO_INCREMENT,
        emailAddress VARCHAR(255) NOT NULL,
        firstName VARCHAR(60)NOT NULL,
        
        PRIMARY KEY (customerID), 
        UNIQUE INDEX emailAddress (emailAddress), 
        INDEX firstName (firstName) 
      );
      </pre>
    </div>
    <h2>A <code>DROP INDEX</code> statement that drops an index</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      DROP INDEX firstName ON customers;
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>An index improves performance when MySQL searches for rows in the table.</li>
        <li>MySQL automatically creates an index for primary keys and for unique constraints.</li>
        <li>You can use the <code>CREATE TABLE</code> statement to create indexes for a table.</li>
        <li>You can use the <code>CREATE INDEX</code> statement to add an index to a table.</li>
        <li>You can use the <code>DROP INDEX</code> statement to drop an index.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>