<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to code a primary key</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to code a primary key</h1>
    <h2>Two column attributes for working with a primary key</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Attribute</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>PRIMARY_KEY</td>
            <td>Specifies that the column is the primary key for the table.</td>
          </tr>
          <tr>
            <td>AUTO_INCREMENT</td>
            <td>Automatically generates an integer value for the column. By default, this value starts at 0 and increments by a value of 1.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>A table with a column-level primary key</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      CREATE TABLE customers ( 
        customerID INT NOT NULL PRIMARY KEY AUTO_INCREMENT,
        emailAddress NOT NULL UNIQUE
      );
      </pre>
    </div>
    <h2>A table with a table-level primary key</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      CREATE TABLE customers (
        customerID INT NOT NULL AUTO_INCREMENT,
        emailAddress NOT NULL UNIQUE,
        
        PRIMARY KEY(customerID)
      );
      </pre>
    </div>
    <h2>A table with a two-column primary key</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      CREATE TABLE orderItems ( 
        orderID INT NOT NULL,
        productID INT NOT NULL,
        itemPrice DECIMAL(10,2) NOT NULL,
        discountAmount DECIMAL(10,2) NOT NULL,
        quantity INT NOT NULL,
        
        PRIMARY KEY (orderID, productID)
      );
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>A primary key requires that each row has unique values for the column or columns that are used for the primary key, and it does not allow NULL values.</li>
        <li>You code a column-level primary key as part of the definition of the column definition. You code a table-level primary key as if it is a separate column definition, and you name its column or columns within that definition.</li>
        <li></li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>