<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to code correlated subqueries</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to code correlated subqueries</h1>
    <h2>Use a correlated subquery in the SELECT clause</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT categoryID, categoryName, (
        SELECT COUNT(*) 
        FROM products 
        WHERE products.categoryID = categories.categoryID
        ) AS productCount 
      FROM categories;
      </pre>
      <img src="corelated.jpg" alt="corelated subquery image" />
    </div>
    <h2>The syntax of a subquery that uses the <code>EXISTS</code> operator</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      WHERE [NOT] EXISTS (subquery)
      </pre>
    </div>
    <h2>Get all customers that don’t have any orders</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT c.customerID, firstName, lastName 
      FROM customers c 
      WHERE NOT EXISTS (
        SELECT * FROM orders o WHERE c.customerID = o.customerID
      );
      </pre>
      <img src="noorders.jpg" alt="customers with no orders image" />
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>A <span style="background-color: yellow;">correlated subquery</span> is a subquery that is executed once for each row processed by the outer query.</li>
        <li>A correlated subquery refers to a value that’s provided by a column in the outer query. Because that value varies depending on the row that’s being processed, each execution of the subquery returns a different result.</li>
        <li>To refer to a value in the outer query, a correlated subquery uses a qualified column name that includes the table name from the outer query. If the subquery uses the same table as the outer query, you must assign a table alias to one of the tables to remove ambiguity.</li>
        <li>You can use the <code>EXISTS</code> operator to test that one or more rows are returned by the subquery. You can also use the <code>NOT</code> operator with the <code>EXISTS </code>operator to test that no rows are returned by the subquery.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>