<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>When and how to use table aliases</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>When and how to use table aliases</h1>
    <h2>The syntax for an inner join that uses table aliases</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT select_list
      FROM table_1 [AS] n1 
      [INNER] JOIN table_2 [AS] n2 ON n1.column_name operator n2.column_name 
      [[INNER] JOIN table_3 [AS] n3 ON n2.column_name operator n3.column_name]...
      </pre>
    </div>
    <h2>An inner join with aliases for all tables</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT firstName, lastName, orderDate
      FROM customers c 
      INNER JOIN orders o ON c.customerID = o.customerID 
      ORDER BY orderDate;
      </pre>
      <img src="tablealiases.jpg" alt="table aliases image" />
    </div>
    <h2>An inner join with aliases for four tables</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT firstName, lastName, o.orderID, productName, itemPrice, quantity
      FROM customers c 
      INNER JOIN orders o ON c.customerID = o.customerID 
      INNER JOIN orderItems oi ON o.orderID = oi.orderID 
      INNER JOIN products p ON oi.productID = p.productID 
      ORDER BY o.orderID;
      </pre>
      <img src="4tables.jpg" alt="4 table aliases image" />
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>A table alias is an alternative table name assigned in the <code>FROM</code> clause.</li>
        <li>The <code>AS</code> keyword is optional.</li>
        <li>If you assign an alias to a table, you must use that alias to refer to the table throughout your query. You can’t use the original table name.</li>
        <li>Use table aliases whenever they simplify or clarify the query. Avoid using them when they make a query more confusing or difficult to read.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>