<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to group queries by column</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to group queries by column</h1>
    <h2>The syntax of the <code>GROUP BY</code> and <code>HAVING</code> clauses</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT select_list 
      FROM table_source 
      [WHERE search_condition] 
      [GROUP BY group_by_list] 
      [HAVING search_condition] 
      [ORDER BY order_by_list];
      </pre>
    </div>
    <h2>Calculate the average list price by category</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT categoryID, COUNT(*) AS productCount, AVG(listPrice) AS averageListPrice 
      FROM products 
      GROUP BY categoryID 
      ORDER BY productCount;
      </pre>
      <img src="group.jpg" alt="group by image" />
    </div>
    <h2>Use columns from multiple tables</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT categoryName, COUNT(*) AS productCount, AVG(listPrice) AS averageListPrice 
      FROM products p 
      JOIN categories c ON p.categoryID = c.categoryID 
      GROUP BY categoryName 
      HAVING averageListPrice > 400;
      </pre>
      <img src="grouptables.jpg" alt="group by image" />
    </div>
    <h2>Use a WHERE clause to filter rows before grouping them</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT categoryName, COUNT(*) AS productCount, AVG(listPrice) AS averageListPrice
      FROM products p 
      JOIN categories c ON p.categoryID = c.categoryID 
      WHERE listPrice > 400 
      GROUP BY categoryName;
      </pre>
      <img src="groupwhere.jpg" alt="group where image" />
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>The <code>GROUP BY</code> clause groups the rows of a result set based on one or more columns or expressions. It’s typically used in <code>SELECT</code> statements that include aggregate functions.</li>
        <li>The <code>HAVING</code> clause specifies a search condition for a group or an aggregate. MySQL applies this condition after it groups the rows that satisfy the condition in the <code>WHERE</code> clause.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>