<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to insert, update, and delete rows</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to insert rows</h1>
    <h2>The syntax of the <code>INSERT</code> statement</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <pre>
      INSERT INTO table_name [(column_list)] 
      VALUES (expression_1 [, expression_2]...)[, (expression_1 [, expression_2]...)]...
      </pre>
    </div>
    <h2>The table definition</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      CREATE TABLE products ( 
        productID INT NOT NULL AUTO_INCREMENT
        categoryID INT NOT NULL,
        productCode VARCHAR(10) NOT NULL,
        productName VARCHAR(255) NOT NULL,
        description TEXT NOT NULL,
        listPrice DECIMAL(10,2) NOT NULL,
        discountPercent DECIMAL(10,2) NOT NULL DEFAULT 0.00,
        dateAdded DATETIMENOT NULL
      ); 
      </pre>
    </div>
    <h2>Add a single row without using a column list</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      INSERT INTO products 
      VALUES (DEFAULT, 1, 'tele', 'Fender Telecaster', 'NA', '949.99', DEFAULT, NOW());
      </pre>
    </div>
    <h2>Add a single row using a column list</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      INSERT INTO products (categoryID, productCode, productName, description, listPrice, dateAdded) 
      VALUES (1, 'tele', 'Fender Telecaster', 'NA', '949.99', NOW());
      </pre>
    </div>
    <h2>Add multiple rows</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      INSERT INTO categories (categoryID, categoryName) 
      VALUES (4, 'Keyboards'), (5, 'Brass'), (6, 'Woodwind');
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>You use the <code>INSERT</code> statement to add a new row to a table.</li>
        <li>In the <code>INSERT</code> clause, you specify the name of the table that you want to add a row to, along with an optional column list.</li>
        <li>If you don’t include a column list, you must specify the column values in the same order as they appear in the table, and you must code a value for each column in the table.</li>
        <li>If you include a column list, you must specify the column values in the same order as they appear in the column list. You can omit columns with default values and columns that accept NULL values.</li>
        <li>To insert a default value, you can use the <code>DEFAULT</code> keyword.</li>
        <li>To insert a NULL value into a column, you can use the NULL keyword.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>