<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to select data from multiple tables</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to select data from multiple tables</h1>
    <h2>How to code an inner join</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
    <h2>The explicit syntax for an <code>inner join</code></h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT select_list 
      FROM table_1 
      [INNER] JOIN table_2 ON join_condition_1 
      [[INNER] JOIN table_3 ON join_condition_2]...
      </pre>
    </div>
    <h2>A SELECT statement that joins the customers and orders tables</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT firstName, lastName, orderDate 
      FROM customers 
      INNER JOIN orders ON customers.customerID = orders.customerID 
      ORDER BY orderDate;
      </pre>
      <img src="join.jpg" alt="join tables image" />
    </div>
    
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>A join is used to combine columns from two or more tables into a result set based on the join conditions you specify. For an inner join, only those rows that satisfy the join condition are included in the result set.</li>
        <li>A join condition names a column in each of the two tables involved in the join and indicates how the two columns should be compared. In most cases, you use the equal operator to retrieve rows with matching columns.</li>
        <li>In most cases, you want to join two tables based on the relationship between the primary key in one table and a foreign key in the other table. However, you can also join tables based on relationships not defined in the database. These are called ad hoc relationships.</li>
        <li>If the two columns in a join condition have the same name, you have to qualify them with the table name so MySQL can distinguish between them. To code a qualified column name, type the table name, followed by a period, followed by the column name.</li>
        <li>The <code>INNER</code> keyword is optional.</li>
        <li>This syntax for coding an inner join can be referred to as the explicit syntax. It is also called the SQL-92 syntax because it was introduced by the SQL-92 standards.</li>
        <li>You can also code an inner join using the implicit syntax. To do that, you list the tables in the FROM clause and code the join condition in the WHERE clause.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>