<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to use the logical operators</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to use the logical operators</h1>
    <h2>The syntax of the <code>WHERE</code> clause with logical operators</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <pre>
      WHERE [NOT] search_condition_1 {AND|OR} [NOT] search_condition_2 ...
      </pre>
    </div>
    <h2>A search condition that uses the <code>AND</code> operator</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      WHERE categoryID = 1 AND discountPercent = 30
      </pre>
    </div>
    <h2>A search condition that uses the <code>OR</code> operator</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      WHERE categoryID = 1 OR discountPercent = 30
      </pre>
    </div>
    <h2>A search condition that uses the <code>NOT</code> operator</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
        NOT listPrice >= 500
      </pre>
    </div>
    <h2>The same condition rephrased to eliminate the <code>NOT</code> operator</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      WHERE listPrice &lt; 500
      </pre>
    </div>
    <h2>A compound condition without parentheses</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT productName, listPrice, discountPercent, dateAdded
      FROM products 
      WHERE dateAdded > '2017-07-01' OR listPrice &lt; 500 
      AND discountPercent > 25;
      </pre>
      <img src="noparens.jpg" alt="without parentheses image" />
    </div>
    <h2>The same compound condition with parentheses</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT productName, listPrice, discountPercent, dateAdded
      FROM products 
      WHERE (dateAdded > '2017-07-01' OR listPrice &lt; 500) 
      AND discountPercent > 25;
      </pre>
      <img src="parens.jpg" alt="with parentheses image" />
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>You can use the <code>AND</code> and <code>OR</code> logical operators to create compound conditions that consist of two or more conditions. You use the <code>AND</code> operator to specify that the search must satisfy both of the conditions, and you use the <code>OR</code> operator to specify that the search must satisfy at least one of the conditions.</li>
        <li>You can use the <code>NOT</code> operator to negate a condition.</li>
        <li>When MySQL evaluates a compound condition, it evaluates the operators in this sequence: (1) <code>NOT</code>, (2) <code>AND</code>, and (3) <code>OR</code>. You can use parentheses to override this order of precedence or to clarify the sequence in which the operations will be evaluated.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>