<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to sort rows with an ORDER BY clause</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to sort rows with an <code>ORDER BY</code> clause</h1>
    <h2>The syntax of the <code>ORDER BY</code> clause</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <pre>
      ORDER BY expression [ASC|DESC] [, expression [ASC|DESC]] ...
      </pre>
    </div>
    <h2>Sort by one column in ascending sequence</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT productName, listPrice, discountPercent 
      FROM products 
      WHERE listPrice &lt; 500 
      ORDER BY productName;
      </pre>
      <img src="sort1asc.jpg" alt="2nd 2 rows image" />
    </div>
    <h2>Sort by one column in descending sequence</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT productName, listPrice, discountPercent 
      FROM products 
      WHERE listPrice &lt; 500 
      ORDER BY listPrice DESC;
      </pre>
      <img src="sort1desc.jpg" alt="2nd 2 rows image" />
    </div>
    <h2>Sort by two columns</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT productName, listPrice, discountPercent 
      FROM products 
      WHERE categoryID = 1 
      ORDER BY discountPercent, listPrice DESC;
      </pre>
      <img src="sort2.jpg" alt="2nd 2 rows image" />
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>The <code>ORDER BY</code> clause specifies how you want the rows in the result set sorted. You can sort by one or more columns, and you can sort each column in either ascending (<code>ASC</code>) or descending (<code>DESC</code>) sequence. <code>ASC</code> is the default.</li>
        <li>By default, in an ascending sort, special characters appear first in the sort sequence, followed by numbers, then by letters (which are not case-sensitive), and then by NULL values. In a descending sort, this sequence is reversed.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>