<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to code subqueries</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>Where to use subqueries</h1>
    <h2>Four ways to introduce a subquery in a SELECT statement</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <ol>
        <li>In a <code>WHERE</code> clause as a search condition</li>
        <li>In a <code>HAVING</code> clause as a search condition</li>
        <li>In the <code>FROM</code> clause as a table specification</li>
        <li>In the <code>SELECT</code> clause as a column specification</li>
      </ol>
    </div>
    <h2>Use a subquery in the <code>WHERE</code> clause</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT productName, listPrice 
      FROM products 
      WHERE listPrice > (
        <span style="background-color: yellow;">SELECT AVG(listPrice)</span>
        <span style="background-color: yellow;">FROM products</span>
        );
      ORDER BY listPrice DESC;
      </pre>
      <h3>The result set</h3> 
      <pre>
      The value returned by the subquery 841.895 
      </pre>
      The result set
      <img src="subquery.jpg" alt="subquery result set image" />      
    </div>
    <h2>Use another subquery in the <code>WHERE</code> clause</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT productName, listPrice 
      FROM products 
      WHERE categoryID = (
        <span style="background-color: yellow;">SELECT categoryID</span> 
        <span style="background-color: yellow;">FROM categories</span> 
        <span style="background-color: yellow;">WHERE categoryName = 'Basses'</span>
        );
      </pre>
      The result set
      <img src="subquerywhere.jpg" alt="2nd 2 rows image" />
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>A <span style="background-color: yellow;">subquery</span> is a <code>SELECT</code> statement that’s coded within another SQL statement.</li>
        <li>A subquery can return a single value, a column that contains multiple values, or multiple columns that contain multiple values.</li>
        <li>A subquery that returns a single value can be coded, or introduced, anywhere an expression is allowed. A subquery that returns a single column can be introduced in place of a list of values, such as the values for an <code>IN</code> clause. And a subquery that returns one or more columns can be introduced in place of a table in the <code>FROM</code> clause.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>