<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to code summary queries</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to code aggregate functions</h1>
    <h2>The syntax of the aggregate functions</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Function syntax</th>
            <th>Resullt</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>AVG(expression)</td>
            <td>The average of the non-NULL values in the expression.</td>
          </tr>
          <tr>
            <td>SUM(expression)</td>
            <td>The total of the non-NULL values in the expression.</td>
          </tr>
          <tr>
            <td>MIN(expression)</td>
            <td>The lowest non-NULL value in the expression.</td>
          </tr>
          <tr>
            <td>MAX(expression)</td>
            <td>The highest non-NULL value in the expression.</td>
          </tr>
          <tr>
            <td>COUNT(expression)</td>
            <td>The number of non-NULL values in the expression.</td>
          </tr>
          <tr>
            <td>COUNT(*)</td>
            <td>The number of rows selected by the query.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>Count all products</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       SELECT COUNT(*) AS productCount 
       FROM products;
      </pre>
      <img src="count.jpg" alt="count() image" />
    </div>
    <h2>Count all orders and orders that have been shipped</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT COUNT(*) AS totalCount, COUNT(shipDate) AS shippedCount 
      FROM orders;
      </pre>
      <img src="shipped.jpg" alt="count(*) image" />
    </div>
    <h2>Find lowest, highest, and average prices</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT MIN(listPrice) AS lowestPrice, MAX(listPrice) AS highestPrice, AVG(listPrice) AS averagePrice 
      FROM products;
      </pre>
      <img src="avg.jpg" alt="aggregate functions image" />
    </div>
    <h2>Get the total of the calculated values for all orders</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      SELECT SUM(itemPrice * quantity – discountAmount) AS ordersTotal 
      FROM orderItems;
      </pre>
      <img src="sum.jpg" alt="sum() image" />
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li><span style="background-color: yellow;">Aggregate functions</span> perform calculations on the values in a set of selected rows. You specify the values to be used in the calculation by coding an expression as the argument.</li>
        <li>In many cases, the expression for an aggregate function is just the name of a column, but it can also be a calculated value that operates on the values in two or more columns.</li>
        <li>A <code>SELECT</code> statement that includes an aggregate function can be called a summary query.</li>
        <li>If you code an aggregate function in the <code>SELECT</code> clause, the <code>SELECT</code> clause can’t include non-aggregate columns from the base table.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>