<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to select rows with a WHERE clause</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to select rows with a <code>WHERE</code> clause</h1>
    <h2>The syntax of the <code>WHERE</code> clause with comparison operators</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <pre>
      WHERE expression_1 operator expression_2
      </pre>
    </div>
    <h2>The comparison operators</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       =    Equal 
       &gt;    Greater than
       &lt;    Less than
       &lt;=   Less than or equal to
       &gt;=   Greater than or equal to
       &lt;&gt;   Not equal
      </pre>
    </div>
    <h2>A <code>WHERE</code> clause that selects products where the product...</h2>
    <h3>Is in the specified category</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      WHERE categoryID = 2
      </pre>
      <img src="2nd.jpg" alt="2nd 2 rows image" />
    </div>
    <h3>Has the specified name</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       WHERE productName = 'Gibson Les Paul'
      </pre>
    </div>
    <h3>Has a list price less than the specified price</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      WHERE listPrice &lt; 499.99
      </pre>
    </div>
    <h3>Has a list price greater than or equal to the specified price</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      WHERE listPrice >= 499.99
      </pre>
    </div>
    <h3>Has a name that starts with the letters A to F</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      WHERE productName &lt; 'G'
      </pre>
    </div>
    <h3>Was added before the specified date</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      WHERE dateAdded &lt; '2017-01-31'
      </pre>
    </div>
    <h3>Was added on or after the specified date</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      WHERE dateAdded &gt;= '2017-01-31'
      </pre>
    </div>
    <h3>Has a discount percent that does not equal the specified amount</h3>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
        discountPercent &lt;&gt; 30
      </pre>
    </div>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>If a comparison results in a <code>TRUE</code> value, the row being tested is included in the result set. If it’s <code>FALSE</code> or unknown, the row isn’t included.</li>
        <li>To use a string literal or a date literal in a comparison, enclose it in single quotes. To use a numeric literal, the single quotes are optional.</li>
        <li>Character comparisons are not case-sensitive.</li>
        <li>You can use a comparison operator to compare any two expressions that result in like data types. Although unlike data types may be converted to data types that can be compared, the comparison may produce unexpected results.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>