<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to work with mysqli</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to work with mysqli</h1>
    <h2>How to connect to a MySQL database (object-oriented)</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $host = 'localhost'; 
      $username = 'mgs_user'; 
      $password = 'pa55word'; 
      $db_name = 'my_guitar_shop1'; 
      @b$db = new mysqli($host, $username, $password, $db_name);
      </pre>
    </div>
    <h2>How to connect to a MySQL database (procedural)</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       $host = 'localhost'; 
       $username = 'mgs_user'; 
       $password = 'pa55word'; 
       $db_name = 'my_guitar_shop1'; 
       @ $db = mysqli_connect($host, $username, $password, $db_name);
      </pre>
    </div>
    <h2>Two properties of the mysqli object for checking connection errors</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Property</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>connect_errno</td>
            <td>Returns the error number if an error occurred. Returns a NULL value if no error occurred.</td>
          </tr>
          <tr>
            <td>connect_error</td>
            <td>Returns the error message if an error occurred. Returns a NULL value if no error occurred.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>How to check for a connection error (object-oriented)</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $connection_error = $db->connect_error; 
      if ($connection_error != null) { 
        echo("Error connecting to database: $connection_error");
        exit(); 
      } 
      </pre>
    </div>
    <h2>How to check for a connection error (procedural)</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $connection_error = mysqli_connect_error(); 
      if ($connection_error != null) { 
        echo("Error connecting to database: $connection_error");
        exit(); 
      }
      </pre>
    </div>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>The mysqli extension includes a <span style="background-color: yellow;">procedural style</span> that uses functions to work with the database, and it includes an <span style="background-color: yellow;">object-oriented style</span> that uses objects, methods, and properties to work with the database.</li>
        <li>To suppress errors, you can begin the line of code that connects to the database with the error <span style="background-color: yellow;">suppression operator</span> (<code>@</code>).</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>