<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to work with prepared statements</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to work with prepared statements</h1>
    <h2>A method of the mysqli class</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Method</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>prepare($sql_statement)</td>
            <td>Prepares the specified SQL statement for execution and returns a mysqli_stmt object. The specified SQL statement can contain zero or more question mark (?) parameters. If an error occurs, this method returns a FALSE value.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>Four methods of the mysqli_stmt class</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Method</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>bind_param($fs, $v1[, $v2]...)</td>
            <td>Binds the specified values to the parameters in the prepared statement. The first parameter is a format string that specifies the data types for all parameters (s for string, i for integer, d for double, b for BLOB).</td>
          </tr>
          <tr>
            <td>bind_result($v1[, $v2]...)</td>
            <td>Binds the columns in the result set to the specified variables.</td>
          </tr>
          <tr>
            <td>execute()</td>
            <td>Executes the prepared statement. Returns TRUE for success and FALSE for failure.</td>
          </tr>
          <tr>
            <td>fetch()</td>
            <td>Gets the values for the result set columns and stores them in the bound variables.</td>
          </tr>
          <tr>
            <td>close()</td>
            <td>Closes the prepared statement.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>How to execute a prepared statement that returns a result set</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $query = "SELECT productCode, productName, listPrice
                FROM products WHERE categoryID = ?";
      $statement = $db->prepare($query);
      $statement->bind_param("i", $category_id); 
      $statement->bind_result($code, $name, $listPrice); 
      $statement->execute();
      </pre>
    </div>
    <h2>How to display the result set</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      &lt;?php while($statement->fetch()) : ?&gt;
      &lt;tr&gt;
        &lt;td&gt;&lt;?php echo($code); ?&gt;&lt;/td&gt;
        &lt;td&gt;&lt;?php echo($name); ?&gt;&lt;/td&gt;
        &lt;td&gt;&lt;?php echo($listPrice); ?&gt;&lt;/td&gt;
      &lt;/tr&gt;  
      &lt;?php endwhile; ?&gt;
      </pre>
    </div>
    <h2>How to close the statement</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $statement->close();
      </pre>
    </div>
    <h2>How to execute a prepared statement that modifies data</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $query = "INSERT INTO products (categoryID, productCode, productName, listPrice) 
                VALUES (?, ?, ?, ?)"; 
      $statement = $db->prepare($query);
      $statement->bind_param("issd", $category_id, $code, $name, $price); 
      $success = $statement->execute(); 
      if ($success) { 
        $count = $db->affected_rows; 
        echo("&lt;p&gt;$count product(s) were added.&lt;/p&gt;");
      } else {
        $error_message = $db->error;
        echo"&lt;p&gt;An error occurred: $error_message.&lt;/p&gt;");
      }
      $statement->close(); 
      </pre>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>