<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to select data</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to select data</h1>
    <h2>A method of the mysqli class for returning a result set</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th></th>
            <th></th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>Method</td>
            <td>Description</td>
          </tr>
          <tr>
            <td>query($select_statement)</td>
            <td>Executes the specified SELECT statement and returns a mysqli object for the result set. If no re-sult set is returned, this method returns a FALSE value.</td>
          </tr>
          <tr>
            <td>real_escape_string($string)</td>
            <td>Escapes special characters in the specified string and returns the new string.</td>
          </tr>
          <tr>
            <td>escape_string($string)</td>
            <td>Same as the real_escape_string method.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>A property and a method of the mysqli_resultset class</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Property/Method</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>num_rows</td>
            <td>The number of rows in the result set.</td>
          </tr>
          <tr>
            <td>fetch_assoc()</td>
            <td>Returns the result set as an associative array.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>How to execute a <code>SELECT</code> statement</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      // Escape the parameters
      $category_id_esc = $db->escape_string($category_id); 
       
      // Execute the statement - manually add single quotes around parameters 
      $query = "SELECT * FROM products WHERE categoryID = '$category_id_esc'";
      $result = $db->query($query); 
       
      // Check the result set 
      if ($result == false) { 
        $error_message = $db->error; 
        echo("An error occurred: $error_message");
        exit;
      } 
      
      // Get the number of rows in the result set 
      $row_count = $result->num_rows;
      </pre>
    </div>
    <h2>How to display the results</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      &lt;?php 
      for ($i = 0; $i &lt; $row_count; $i++) : 
        $product = $result->fetch_assoc(); 
      ?&gt;
      &lt;tr&gt;
        &lt;td&gt;&lt;?php echo $product['productID']; ?&gt;&lt;/td&gt;
        &lt;td&gt;&lt;?php echo $product['categoryID']; ?&gt;&lt;/td&gt;
        &lt;td&gt;&lt;?php echo $product['productName']; ?&gt;&lt;/td&gt;
        &lt;td&gt;&lt;?php echo $product['productCode']; ?&gt;&lt;/td&gt;
        &lt;td&gt;&lt;?php echo $product['listPrice']; ?&gt;&lt;/td&gt;
      &lt;/tr&gt;
      </pre>
    </div>
    <h2>How to free resources used by the result set and database connection</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       // close the result set
       $result->free();
       
       // close the db connection
       $db->close(); 
      </pre>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>