<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>The object-oriented style compared to the procedural style</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>The object-oriented style compared to the procedural style</h1>
    <h2></h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <pre>
      $result = $db->query($query); // oo
      $result = mysqli_query($db, $query); // procedural
      
      $error_message = $db->error; // oo
      $error_message = mysqli_error($db); // procedural
      
      $row = $result->fetch_assoc(); // oo
      $row = mysqli_fetch_assoc($result); // procedural
      
      $row_count = $result->num_rows; // oo
      $row_count = mysqli_num_rows($result); // procedural
      
      $count = $db->affected_rows; // oo
      $count = mysqli_affected_rows($db); // procedural
      
      $result->free(); // oo
      $result->free(); mysqli_free_result($result); // procedural
      
      $statement = $db->prepare($query); // oo      
      $statement = mysqli_prepare($db, $query); // procedural
      
      $statement->bind_param("i", $category_id); // oo      
      mysqli_bind_param($statement, "i", $category_id); // procedural
      
      $success = $statement->execute(); // oo      
      $success = mysqli_execute($statement); 
      
      $db->close(); // oo
      mysqli_close($db); // procedural
      </pre>
    </div>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>For every object-oriented call to the mysqli extension, there is a corresponding procedural call.</li>
        <li>The object-oriented calls don’t include parentheses when they call a property, but they do include parentheses when they call a method.</li>
        <li>The procedural calls always begin with "mysqli_" and include the parentheses at the end of the function.</li>
        <li>The procedural calls usually pass the database connection, the result set, or the prepared statement to the function as its first argument.</li>
        <li>The object-oriented calls require less code than the corresponding procedural calls.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>