<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to work with PDO</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to work with PDO</h1>
    <h2>How to connect to a database</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $dsn = "mysql:host=bscacad3.buffalostate.edu;dbname=<em>your-bsc-userid</em>";
      $username = "<em>your-bsc-userid</em>";
      $password = "<em>your-Banner-id</em>";
      $db = new PDO($dsn, $username, $password); // creates PDO object      
      </pre>
    </div>
    <h2>Two methods of the PDO class for selecting data</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Method</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>query($select_statement)</td>
            <td>Executes the specified SQL SELECT statement and returns a PDOStatement object that contains the result set. If no result set is returned, this method returns a FALSE value.</td>
          </tr>
          <tr>
            <td>query($input)</td>
            <td>Places quotes around the input and escapes special characters.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>A <code>query()</code> method with the <code>SELECT</code> statement coded in a variable</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       $query = 'SELECT * FROM products WHERE categoryID = 1 ORDER BY productID';
       $products = $db->query($query); // $products contains the result set
      </pre>
    </div>
    <h2>A <code>query()</code> method with the <code>SELECT</code> statement coded as an argument</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $products = $db->query('SELECT * FROM products');
      </pre>
    </div>
    <h2>An unquoted parameter (<span style="color: #F00; font-weight: bold;">not secure!</span>)</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $query = "SELECT productCode, productName, listPrice FROM products 
                WHERE productID = $product_id"; 
      $products = $db->query($query);
      </pre>
    </div>
    <h2>A quoted parameter (<span style="color: #F00; font-weight: bold;">more secure</span>)</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $product_id_q = $db->quote($product_id); 
      $query = "SELECT productCode, productName, listPrice FROM products 
                WHERE productID = $product_id_q"; 
      $products = $db->query($query); 
      </pre>
    </div>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>To execute a dynamic <code>SELECT</code> statement, you use the query() method of the PDO object. It requires just one argument, which is the <code>SELECT</code> statement to be executed. This argument can be a variable that contains the SELECT statement or the statement itself.</li>
        <li>If the <code>SELECT</code> statement returns a result set, the <code>query()</code> method returns the result set in a PDOStatement object. Then, you can get the data from the result set by using the techniques described in chapter 2.</li>
        <li>Data that’s input by users can be malicious. To protect against this, you can use the <code>quote()</code> method or prepared statements.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>