<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to set the error mode for PDO</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to set the error mode for PDO</h1>
    <h2>The three error modes for PDO</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Name</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>ERRMODE_SILENT</td>
            <td>This is the default error mode. PDO sets the error in the database or statement object, but it doesn’t emit a PHP warning message or throw an exception. To access the error, you can use the <code>errorCode()</code> and <code>errorInfo()</code> methods on the database or statement object. However, this requires you to check the error code after each database call.</td>
          </tr>
          <tr>
            <td>ERRMODE_WARNING</td>
            <td>PDO sets the error and doesn’t throw an exception as in "silent" mode, but does emit a PHP warning message. This setting is useful during testing and debugging.</td>
          </tr>
          <tr>
            <td>ERRMODE_EXCEPTION</td>
            <td>PDO sets the error as in "silent" mode and throws a PDOException object that reflects the error code and error message. This setting is also useful during testing and debugging, and it makes it easier for you to structure your error-handling code.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>How to use the constructor of the PDO class to set the error mode</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $dsn = 'mysql:host=localhost;dbname=my_guitar_shop2'; 
      $username = 'mgs_user'; 
      $password = 'pa55word'; 
      $options = array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION); 
      try { 
        $db = new PDO($dsn, $username, $password, $options); 
      } catch (PDOException $e) {
        $error_message = $e->getMessage();
        echo("Error connecting to database: $error_message&lt;br /&gt;"); 
        exit(); 
      } 
      </pre>
    </div>
    <h2>How to use the <code>setAttribute()</code> method to set the error mode</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
      </pre>
    </div>
    <h2>How to use a try/catch statement to catch PDOException objects</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      try {
        $query = 'SELECT * FROM product'; 
        $statement = $db->prepare($query); 
        $statement->execute(); 
        $products = $statement->fetchAll(); 
        $statement->closeCursor(); 
      } catch (PDOException $e) { 
        $error_message = $e->getMessage(); 
        echo("Database error: $error_message&lt;br /&gt;");
        exit(); 
      }
      </pre>
    </div>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>When you use PDO to execute SQL statements, you can choose between one of three error modes. Of these error modes, we recommend the “exception” error mode.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>