<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to insert, update, and delete using PDO</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to insert, update, and delete using PDO</h1>
    <h2>A method of the PDO class for inserting, updating, and deleting data</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Method</th>
            <th>Description</th>
            <th></th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>exec($sql_statement)</td>
            <td>Executes the specified SQL statement and returns the number of affected rows. If no rows were affected, the method returns zero.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>How to execute an <code>INSERT</code> statement</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       $category_id_q = $db->quote($category_id); 
       $code_q = $db->quote($code); 
       $name_q = $db->quote($name); 
       $price_q = $db->quote($price); 
       $query = "INSERT INTO products 
                 VALUES (categoryID, productCode, productName, listPrice) 
                 ($category_id_q, $code_q, $name_q, $price_q)"; 
       $insert_count = $db->exec($query);
      </pre>
    </div>
    <h2>How to execute an <code>UPDATE</code> statement</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $product_id_q = $db->quote($product_id);
      $price_q = $db->quote($price); 
      $query = "UPDATE products SET listPrice = $price_q 
                WHERE productID = $product_id_q"; 
      $update_count = $db->exec($query);
      </pre>
    </div>
    <h2>How to execute a <code>DELETE</code> statement</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
       $product_id_q = $db->quote($product_id); 
       $query = "DELETE FROM products WHERE productID = $product_id_q"; 
       $delete_count = $db->exec($query); 
      </pre>
    </div>
    <h2>How to display the row counts</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      &lt;p&gt;Insert count: &lt;?php echo $insert_count; ?&gt;&lt;/p&gt;
      &lt;p&gt;Update count: &lt;?php echo $update_count; ?&gt;&lt;/p&gt;
      &lt;p&gt;Delete count: &lt;?php echo $delete_count; ?&gt;&lt;/p&gt;
      </pre>
    </div>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>To execute an <code>INSERT</code>, <code>UPDATE</code>, or <code>DELETE</code> statement, you use the <code>exec()</code> method of the PDO object with the SQL statement as the argument.</li>
        <li>The <code>exec()</code> method returns a value that represents the number of rows that were affected, and this value can be assigned to a variable.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>