<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to use basic authentication</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to use basic authentication</h1>
    <h2>A login dialog box</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <img src="box.jpg" alt="login dialog box image" style="width: 471px; height: 207px;"  /> <!-- 942x415 -->
    </div>
    <h2>A protected page</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <img src="prot.jpg" alt="protected page image" style="width: 471px; height: 207px;"  /> <!-- 942x415 -->
    </div>
    <h2>The unauthorized page</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <img src="unauth.jpg" alt="unauthorized page image" style="width: 471px; height: 207px;"  /> <!-- 942x415 -->
    </div>
    <h2>The $_SERVER array</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Index</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>PHP_AUTH_USER</td>
            <td>Returns the username from the authentication dialog box or a NULL value if the dialog box hasn’t been displayed.</td>
          </tr>
          <tr>
            <td>PHP_AUTH_PW</td>
            <td>Returns the password from the authentication dialog box or a NULL value if the dialog box hasn’t been displayed.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>Code that forces a valid admin user (<code>util/valid_admin.php</code>)</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      &lt;?php
require_once('model/database.php');
require_once('model/admin_db.php');

$email = '';
$password = '';    
if (isset($_SERVER['PHP_AUTH_USER']) && isset($_SERVER['PHP_AUTH_PW'])) {
    $email = $_SERVER['PHP_AUTH_USER'];
    $password = $_SERVER['PHP_AUTH_PW'];    
}

if (!is_valid_admin_login($email, $password)) {
    header('WWW-Authenticate: Basic realm="Admin"');
    header('HTTP/1.0 401 Unauthorized');
    include('unauthorized.php');
    exit();
}
?&gt;
      </pre>
    </div>
    <h2>Code that’s included at the top of the each protected page</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      &lt;?php 
      require_once('util/secure_conn.php'); // require a secure connection
      require_once('util/valid_admin.php'); // require a valid admin user
      ?&gt;      
      </pre>
    </div>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>The 401 (Unauthorized) response header doesn’t display the requested page and causes most modern browsers to display a dialog box that prompts the user for a username and password.in this figure.</li>
        <li>The WWW-Authenticate header must also be included in a 401 (Unauthorized) response. This header can specify the type of authentication (usually Basic) and a name for the authentication realm.</li>
        <li>The code at the top of all protected pages should force a secure connection. To do that, it can include a <code>secure_conn.php</code> file like the one shown on this page.</li>
        <li>The code at the top of all protected pages should also force a valid admin user. To do that, it can include a <code>valid_admin.php</code> file like the one shown on this page.</li>
        <li>Due to a bug, you can’t use the filter_input() function to access the PHP_AUTH_USER and PHP_AUTH_PW indexes of the $_SERVER array. As a result, you must access them directly.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>