<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to encrypt and decrypt data</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to encrypt and decrypt data</h1>
    <h2>Some methods of the Key class in the Defuse\Crypto namespace</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Method</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>createNewRandomKey()</td>
            <td>A static method that generates a new Key object.</td>
          </tr>
          <tr>
            <td>saveToAsciiSafeString()</td>
            <td>A regular method that converts the Key object to an ASCII string.</td>
          </tr>
          <tr>
            <td>loadFromAsciiSafeString($keyAscii)</td>
            <td>A static method that converts the ASCII string to a Key object.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>Some methods of the Crypto class in the Defuse\Crypto namespace</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Method</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>encrypt($data, $key)</td>
            <td>A static method that uses the specified Key object to encrypt the specified data.</td>
          </tr>
          <tr>
            <td>decrypt($data, $key)</td>
            <td>A static method that uses the specified Key object to decrypt the specified data.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2Code that creates an encryption key and saves it to a file></h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      require_once('/xampp/ph
      p/lib/defuse-crypto.phar'); 
      use Defuse\Crypto\Key;
      $key = Key::createNewRandomKey(); 
      $keyAscii = $key->saveToAsciiSafeString(); 
      file_put_contents('/xampp/php/defuse-key.txt', $keyAscii);
      </pre>
    </div>
    <h2>Code that encrypts and decrypts data</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      require_once('/xampp/php/lib/defuse-crypto.phar'); 
      use Defuse\Crypto\Key; 
      use Defuse\Crypto\Crypto; 
      use Defuse\Crypto\Exception\WrongKeyOrModifiedCiphertextException; 
      
      // set up credit card variable 
      $credit_card_no = '4111111111111111'; 
      
      // get encryption key 
      $keyAscii = file_get_contents('/xampp/php/defuse-key.txt'); 
      $key = Key::loadFromAsciiSafeString($keyAscii); 
      
      // encrypt data 
      $encrypted_data = Crypto::encrypt($credit_card_no, $key); 
      echo("Encrypted data: $encrypted_data&lt;br />&gt;");

      // decrypt data 
      try {
        $decrypted_data = Crypto::decrypt($encrypted_data, $key); 
        echo("Decrypted data: $decrypted_data&lt;br />&gt;");
      } catch (WrongKeyOrModifiedCiphertextException $ex) { 
        echo("Exception: : . $ex->getMessage() . "&lt;br />&gt'");
      }        
      </pre>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>