<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to use form-based authentication</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to use form-based authentication</h1>
    <h2>A login form</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <img src="login.jpg" alt="login image" style="width: 471px; height: 207px;" /> <!-- 942x415 -->
    </div>
    <h2>A protected page</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <img src="prot.jpg" alt="protected page image" style="width: 471px; height: 207px;"  /> <!-- 942x415 -->
    </div>
    <h2>A utility file that forces a valid admin user (util/valid_admin.php)</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      &lt;?php
require_once('model/database.php');
require_once('model/admin_db.php');

$email = '';
$password = '';    
if (isset($_SERVER['PHP_AUTH_USER']) && isset($_SERVER['PHP_AUTH_PW'])) {
    $email = $_SERVER['PHP_AUTH_USER'];
    $password = $_SERVER['PHP_AUTH_PW'];    
}

if (!is_valid_admin_login($email, $password)) {
    header('WWW-Authenticate: Basic realm="Admin"');
    header('HTTP/1.0 401 Unauthorized');
    include('unauthorized.php');
    exit();
}
?&gt;
      </pre>
    </div>
    <h2>Code that’s included at the top of the login page</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      &lt;?php 
      require_once('util/secure_conn.php'); // require a secure connection
      ?&gt;
      </pre>
    </div>
    <h2>Code that’s included at the top of the other protected pages</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      &lt;?php 
      require_once('util/secure_conn.php'); // require a secure connection
      require_once('util/valid_admin.php'); // require a valid admin user
      ?&gt;      
      </pre>
    </div>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>You can use a utility file like the valid_admin.php file to redirect to the controller if the user isn’t logged in as a valid administrator.</li>
        <li>The code at the top of the login page should force the page to use a secure connection.</li>
        <li>The code at the top of each protected page should force a secure connection. To do that, it can include a utility file that forces the connection.</li>
        <li>The code at the top of each protected page should also force a valid admin user. To do that, it can include a utility file like the valid_admin.php file on this page.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>