<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to store and validate a password</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to store and validate a password</h1>
    <h2>Two functions for working with passwords</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Function</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>password_hash($password, $algorithm)</td>
            <td>Creates a new hash of the password using a strong salt and a strong one-way encryption algorithm.</td>
          </tr>
          <tr>
            <td>password_verify($password, $hash</td>
            <td>Returns TRUE if the specified password matches the specified hash.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>Two constants for setting the algorithm for the password</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Constant</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>PASSWORD_BCRYPT</td>
            <td>Uses the bcrypt algorithm to create a hash that’s 60 characters long.</td>
          </tr>
          <tr>
            <td>PASSWORD_DEFAULT</td>
            <td>Uses the default algorithm of the password_hash() function. With PHP 5.5 and 7.1, the default algorithm is bcrypt. However, this default may change as newer and stronger algorithms become available. This may cause the number of characters in the hash to increase beyond the current 60 characters.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>Code that hashes a password using the default algorithm</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $password = 's3sam3'; 
      $hash = password_hash($password, PASSWORD_DEFAULT); // up to 255 chars
      </pre>
    </div>
    <h2>Code that verifies whether a password is valid</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $valid_password = password_verify('s3sam3', 
                        '$2y$10$xIqN2cVy8HVuKNKUwxFQR.xRP9oRj.FF8r52spVc.XCaEFy7iLHmu');
      if ($valid_password) { 
        echo("Password is valid.&lt;/p&gt;");
      }
      </pre>
    </div>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>A <span style="background-color: yellow;">hash</span> function accepts a variable-size string and uses an algorithm to encrypt it and return a fixed-size string known as a hash. Hash functions are one-way functions that are only designed to encrypt, not decrypt.</li>
        <li>In a hash function, the original string is sometimes called the <span style="background-color: yellow;">message</span>, and the hash is sometimes called the <span style="background-color: yellow;">digest</span>.</li>
        <li>A <span style="background-color: yellow;">salt</span> is some random data that’s added to the password before the password is hashed. This makes the hash stronger and more difficult to decrypt.</li>
        <li>A <span style="background-color: yellow;">cipher</span> is a type of algorithm that’s used in cryptography.</li>
        <li>The <span style="background-color: yellow;">bcrypt</span> algorithm is a hashing algorithm based on the Blowfish cipher.</li>
        <li>With PHP 5.5 and later, it’s considered a best practice to use the <code>password_hash()</code> and <code>password_verify()</code> functions to hash passwords and to verify whether the hashes are valid.</li>
        <li>If you use the <code>PASSWORD_DEFAULT</code> constant with the <code>password_hash()</code> function, it’s considered a best practice to store the hash in a database column that can accept 255 characters.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>