<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to redirect to a secure connection</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to redirect to a secure connection</h1>
    <h2The $_SERVER array></h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Index</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>HTTPS</td>
            <td>Returns a non-empty value if the current request is using HTTPS.</td>
          </tr>
          <tr>
            <td>HTTP_HOST</td>
            <td>Returns the host for the current request.</td>
          </tr>
          <tr>
            <td>REQUEST_URI</td>
            <td>Returns the URI (Uniform Resource Identifier) for the current request.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>A utility file (<code>util/secure_conn.php</code>) that redirects a page to a secure connection</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      &lt;?php
      // make sure the page uses a secure connection 
      $https = filter_input(INPUT_SERVER, 'HTTPS'); 
      if (!$https) { 
        $host = filter_input(INPUT_SERVER, 'HTTP_HOST'); 
        $uri = filter_input(INPUT_SERVER, 'REQUEST_URI');
        $url = 'https://' . $host . $uri; header("Location: " . $url); 
        exit(); 
      } 
      ?&gt;
      </pre>
    </div>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>The <code>$_SERVER<code> array contains information about headers and paths. This data is set by your web server, and the code above works for most versions of Apache.</li>
        <li>Unfortunately, all web servers don’t set the values in the <code>$_SERVER array</code> the same way. So, if this code doesn’t work for your web server, you need to adjust it so it does.</li>
        <li>You can use the <code>filter_input()</code> function to get the values for the indexes of the <code>$_SERVER</code> array.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>