<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to read and write part of a file</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to read and write part of a file</h1>
    <h2>Modes used when opening a file with the <code>fopen()</code> function</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Mode</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>'rb'</td>
            <td>Opens the file for reading. If the file doesn’t exist, fopen() returns FALSE.</td>
          </tr>
          <tr>
            <td>'wb'</td>
            <td>Opens the file for writing. If the file exists, the existing data is deleted. If the file doesn’t exist, it is created.</td>
          </tr>
          <tr>
            <td>'ab'</td>
            <td>Opens the file for writing. If the file exists, the new data is appended. If the file doesn’t exist, it is created.</td>
          </tr>
          <tr>
            <td>'xb'</td>
            <td>Creates a new file for writing. If the file exists, fopen() returns FALSE.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>Functions that open and close a file</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Function</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>fopen($path, $mode)</td>
            <td>Opens the specified file with the specified mode and returns a file handle.</td>
          </tr>
          <tr>
            <td>feof($file)</td>
            <td>Returns TRUE when the end of the specified file is reached.</td>
          </tr>
          <tr>
            <td>fclose($file)</td>
            <td>Closes the specified file.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>Functions that read from and write to a file</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Function</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>fread($file, $length)</td>
            <td>Reads up to the specified number of bytes from the specified file.</td>
          </tr>
          <tr>
            <td>fgets($file) </td>
            <td>Reads a line from the specified file.</td>
          </tr>
          <tr>
            <td>fwrite($file, $data)</td>
            <td>Writes the specified string data to the specified file.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>Read from a file</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $file = fopen('usernames.txt', 'rb'); 
      $names = "";
      while (!feof($file)) {
        $name = fgets($file);
        if ($name === false) {
          continue;
        }
        $name = trim($name); 
        if (strlen($name) == 0 || substr($name, 0, 1) == '#') {
          continue;
        }
        $names .= "&lt;div&gt;$name&lt;/div&gt;";
      } 
      fclose($file);
      echo $names;
      </pre>
    </div>
    <h2>Write to a file</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      $path = getcwd(); 
      $items = scandir($path); 
      $file = fopen('listing.txt', 'wb'); 
      foreach ($items as $item) {
        $item_path = $path . DIRECTORY_SEPARATOR . $item; 
        if (is_dir($item_path)) {
          fwrite($file, $item . "\n");
        } 
      } 
      fclose($file);
      </pre>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>