<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to read and write images</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>
    <h1>How to read and write images</h1>
    <h2>Functions that work with images</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Name</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>imagecreatefromxxx($path)</td>
            <td>Creates an image of the xxx type from the specified file path.</td>
          </tr>
          <tr>
            <td>imagesx($image)</td>
            <td>Returns the width of the specified image.</td>
          </tr>
          <tr>
            <td>imagesy($image)</td>
            <td>Returns the height of the specified image.</td>
          </tr>
          <tr>
            <td>imagexxx($image, $path)</td>
            <td>Writes the specified image of the xxx type to the specified file path.</td>
          </tr>
          <tr>
            <td>imagedestroy($image)</td>
            <td>Frees any memory that’s used for the specified image.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>Code that reads and writes an image</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      // Set the paths for the images
      $image_path = getcwd() . DIRECTORY_SEPARATOR . 'gibson_sg.png'; 
      $image_path_2 = getcwd() . DIRECTORY_SEPARATOR . 'gibson_sg_2.png';

      // Get the image width, height, and type 
      $image_info = getimagesize($image_path); 
      $image_type = $image_info[2]; 
      
      // Set up the function names for the image type 
      switch($image_type) {
        case IMAGETYPE_JPEG: 
          $image_from_file = 'imagecreatefromjpeg';
          $image_to_file = 'imagejpeg'; 
          break; 
        case IMAGETYPE_GIF:
          $image_from_file = 'imagecreatefromgif';
          $image_to_file = 'imagegif';
          break; 
        case IMAGETYPE_PNG:
          $image_from_file = 'imagecreatefrompng';
          $image_to_file = 'imagepng';
          break; 
        default: 
          echo("File must be a JPEG, GIF, or PNG image.&lt;br /&gt;"); 
          exit; 
      }
      
      // Create a new image from the file 
      $image = $image_from_file($image_path); 
      
      // Check the image's width and height 
      $image_width = imagesx($image); 
      $image_height = imagesy($image); 
      
      // Write the image to a file 
      $image_to_file($image, $image_path_2); 
      
      // Free any memory associated with the image 
      imagedestroy($image);
      </pre>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>