<!doctype html>
<?php
  date_default_timezone_set("America/New_York");
?>
<html lang="en">
  <head>
    <title>How to work with transparency</title>
    <link href="https://jimgerland.com/includes/css/styles.css" rel="stylesheet" />
    <link href="https://jimgerland.com/includes/css/codestyles.css" rel="stylesheet" />   
    <style>
      table, th, td {
        font-family: Verdana, Arial, Sans-Serif;
        font-size: large;
      }
    </style>
  </head>
  <body>How to work with transparency
    <h1></h1>
    <h2>Functions that work with image transparency</h2>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
      <table>
        <thead>
          <tr>
            <th>Name</th>
            <th>Description</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>imagecolorallocatealpha($i, $r, $g, $b, $a)</td>
            <td>Returns an identifier for the transparent (alpha) color of the specified image. The RGB values specify the color. The alpha value specifies the amount of transparency. This value can range from 0 to 127 with 127 being completely transparent.</td>
          </tr>
          <tr>
            <td>imagecolortransparent($i, $a)</td>
            <td>Sets the transparent color in the specified image.</td>
          </tr>
          <tr>
            <td>imagealphablending($i, $f)</td>
            <td>To turn alpha blending mode off, set the second parameter to FALSE.</td>
          </tr>
          <tr>
            <td>imagesavealpha($i, $f)</td>
            <td>To attempt to save full alpha channel information, set the second parameter to TRUE. For this to work, alpha blending mode must be turned off.</td>
          </tr>
        </tbody>
      </table>
    </div>
    <h2>Code that works with the transparency of an image</h2>
    <div style="font-family: Courier, Arial, Sans-Serif; font-size: large;">
      <pre>
      // code that calculates the width and height for the new image 
      // and sets the image type for the new image 
      $new_image = imagecreatetruecolor($new_width, $new_height);

      // Set transparency according to image type 
      if ($image_type == IMAGETYPE_GIF) {
        $alpha = imagecolorallocatealpha($new_image, 0, 0, 0, 127);
        imagecolortransparent($new_image, $alpha);
      } 
      if ($image_type == IMAGETYPE_PNG || $image_type == IMAGETYPE_GIF) {
        imagealphablending($new_image, false);
        imagesavealpha($new_image, true);
        
      } // code that writes the new image to a file      
      </pre>
    </div>
    <div style="font-family: Verdana, Arial, Sans-Serif; font-size: large;">
    <h2>Description</h2>
      <ul>
        <li>Transparency refers to portions of an image that are transparent. Although JPEG images don’t provide for transparency, GIF and PNG images do provide for it.</li>
        <li>A transparent image stores RGB values for the colors, and it stores an alpha channel that provides additional information about the transparency.</li>
        <li>When a transparent image is displayed, the browser combines the transparent parts of the image with the background to create the transparency effect. This process is known as alpha blending.</li>
      </ul>
    </div>
    <p><a href=".">Back</a></p>
  </body>
</html>